# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/dynamic/gw/gateway.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/dynamic/gw/gateway.proto\x12\x18\x62ilibili.dynamic.gateway\x1a\x19google/protobuf/any.proto\"/\n\x07\x41\x64Param\x12\x10\n\x08\x61\x64_extra\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\xa1\x02\n\x0e\x41\x64\x64itionCommon\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12:\n\x06\x62utton\x18\x07 \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionalButton\x12\x11\n\thead_icon\x18\x08 \x01(\t\x12\x33\n\x05style\x18\t \x01(\x0e\x32$.bilibili.dynamic.gateway.ImageStyle\x12\x0c\n\x04type\x18\n \x01(\t\x12\x11\n\tcard_type\x18\x0b \x01(\t\"\xbd\x01\n\x0e\x41\x64\x64itionEsport\x12\x34\n\x05style\x18\x01 \x01(\x0e\x32%.bilibili.dynamic.gateway.EspaceStyle\x12L\n\x14\x61\x64\x64ition_esport_moba\x18\x02 \x01(\x0b\x32,.bilibili.dynamic.gateway.AdditionEsportMobaH\x00\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x11\n\tcard_type\x18\x04 \x01(\tB\x06\n\x04item\"\xc5\x02\n\x12\x41\x64\x64itionEsportMoba\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x37\n\nmatch_team\x18\x03 \x03(\x0b\x32#.bilibili.dynamic.gateway.MatchTeam\x12W\n\x1b\x61\x64\x64ition_esport_moba_status\x18\x04 \x01(\x0b\x32\x32.bilibili.dynamic.gateway.AdditionEsportMobaStatus\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12:\n\x06\x62utton\x18\x06 \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionalButton\x12\x11\n\tsub_title\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\n \x01(\t\x12\x11\n\tcard_type\x18\x0b \x01(\t\"\xbf\x01\n\x18\x41\x64\x64itionEsportMobaStatus\x12`\n addition_esport_moba_status_desc\x18\x01 \x03(\x0b\x32\x36.bilibili.dynamic.gateway.AdditionEsportMobaStatusDesc\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\x05\x12\r\n\x05\x63olor\x18\x04 \x01(\t\x12\x13\n\x0bnight_color\x18\x05 \x01(\t\"Q\n\x1c\x41\x64\x64itionEsportMobaStatusDesc\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12\x13\n\x0bnight_color\x18\x03 \x01(\t\"\x9f\x01\n\rAdditionGoods\x12\x11\n\trcmd_desc\x18\x01 \x01(\t\x12\x38\n\x0bgoods_items\x18\x02 \x03(\x0b\x32#.bilibili.dynamic.gateway.GoodsItem\x12\x11\n\tcard_type\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x13\n\x0bsource_type\x18\x06 \x01(\x05\"\xa0\x02\n\nAdditionUP\x12\r\n\x05title\x18\x01 \x01(\t\x12<\n\x0b\x64\x65sc_text_1\x18\x02 \x01(\x0b\x32\'.bilibili.dynamic.gateway.HighlightText\x12\x13\n\x0b\x64\x65sc_text_2\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12:\n\x06\x62utton\x18\x05 \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionalButton\x12\x11\n\tcard_type\x18\x06 \x01(\t\x12\x15\n\rreserve_total\x18\x07 \x01(\x03\x12=\n\x08\x61\x63t_skin\x18\x08 \x01(\x0b\x32+.bilibili.dynamic.gateway.AdditionalActSkin\"\xad\x01\n\x0b\x41\x64\x64itionUgc\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x10\n\x08\x64uration\x18\x07 \x01(\t\x12\x11\n\tline_feed\x18\x08 \x01(\x08\x12\x11\n\tcard_type\x18\t \x01(\t\"b\n\x0c\x41\x64\x64itionVote\x12\x11\n\timage_url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0e\n\x06text_1\x18\x03 \x01(\t\x12\x13\n\x0b\x62utton_text\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\"\x8c\x05\n\rAdditionVote2\x12\x46\n\x12\x61\x64\x64ition_vote_type\x18\x01 \x01(\x0e\x32*.bilibili.dynamic.gateway.AdditionVoteType\x12\x0f\n\x07vote_id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\x12\x10\n\x08\x64\x65\x61\x64line\x18\x05 \x01(\x03\x12\x11\n\topen_text\x18\x06 \x01(\t\x12\x12\n\nclose_text\x18\x07 \x01(\t\x12\x12\n\nvoted_text\x18\x08 \x01(\t\x12:\n\x05state\x18\t \x01(\x0e\x32+.bilibili.dynamic.gateway.AdditionVoteState\x12H\n\x12\x61\x64\x64ition_vote_word\x18\n \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionVoteWordH\x00\x12\x46\n\x11\x61\x64\x64ition_vote_pic\x18\x0b \x01(\x0b\x32).bilibili.dynamic.gateway.AdditionVotePicH\x00\x12N\n\x15\x61\x64\x64ition_vote_defaule\x18\x0c \x01(\x0b\x32-.bilibili.dynamic.gateway.AdditionVoteDefauleH\x00\x12\x10\n\x08\x62iz_type\x18\r \x01(\x05\x12\r\n\x05total\x18\x0e \x01(\x03\x12\x11\n\tcard_type\x18\x0f \x01(\t\x12\x0c\n\x04tips\x18\x10 \x01(\t\x12\x0b\n\x03uri\x18\x11 \x01(\t\x12\x10\n\x08is_voted\x18\x12 \x01(\x08\x12\x12\n\nchoice_cnt\x18\x13 \x01(\x05\x12\x1c\n\x14\x64\x65\x66\x61ule_select_share\x18\x14 \x01(\x08\x42\x06\n\x04item\"$\n\x13\x41\x64\x64itionVoteDefaule\x12\r\n\x05\x63over\x18\x01 \x03(\t\"N\n\x0f\x41\x64\x64itionVotePic\x12;\n\x04item\x18\x01 \x03(\x0b\x32-.bilibili.dynamic.gateway.AdditionVotePicItem\"\x8c\x01\n\x13\x41\x64\x64itionVotePicItem\x12\x0f\n\x07opt_idx\x18\x01 \x01(\x05\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0f\n\x07is_vote\x18\x03 \x01(\x08\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x0f\n\x07persent\x18\x05 \x01(\x01\x12\r\n\x05title\x18\x06 \x01(\t\x12\x15\n\ris_max_option\x18\x07 \x01(\x08\"P\n\x10\x41\x64\x64itionVoteWord\x12<\n\x04item\x18\x01 \x03(\x0b\x32..bilibili.dynamic.gateway.AdditionVoteWordItem\"~\n\x14\x41\x64\x64itionVoteWordItem\x12\x0f\n\x07opt_idx\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07is_vote\x18\x03 \x01(\x08\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x0f\n\x07persent\x18\x05 \x01(\x01\x12\x15\n\ris_max_option\x18\x06 \x01(\x08\"I\n\x11\x41\x64\x64itionalActSkin\x12\x0c\n\x04svga\x18\x01 \x01(\t\x12\x12\n\nlast_image\x18\x02 \x01(\t\x12\x12\n\nplay_times\x18\x03 \x01(\x03\"\xad\x03\n\x10\x41\x64\x64itionalButton\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.bilibili.dynamic.gateway.AddButtonType\x12\x43\n\njump_style\x18\x02 \x01(\x0b\x32/.bilibili.dynamic.gateway.AdditionalButtonStyle\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12@\n\x07uncheck\x18\x04 \x01(\x0b\x32/.bilibili.dynamic.gateway.AdditionalButtonStyle\x12>\n\x05\x63heck\x18\x05 \x01(\x0b\x32/.bilibili.dynamic.gateway.AdditionalButtonStyle\x12@\n\x06status\x18\x06 \x01(\x0e\x32\x30.bilibili.dynamic.gateway.AdditionalButtonStatus\x12G\n\nclick_type\x18\x07 \x01(\x0e\x32\x33.bilibili.dynamic.gateway.AdditionalButtonClickType\"\\\n\x1b\x41\x64\x64itionalButtonInteractive\x12\x0e\n\x06popups\x18\x01 \x01(\t\x12\x0f\n\x07\x63onfirm\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61ncel\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\"\x85\x02\n\x15\x41\x64\x64itionalButtonStyle\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12J\n\x0binteractive\x18\x03 \x01(\x0b\x32\x35.bilibili.dynamic.gateway.AdditionalButtonInteractive\x12<\n\x08\x62g_style\x18\x04 \x01(\x0e\x32*.bilibili.dynamic.gateway.AddButtonBgStyle\x12\r\n\x05toast\x18\x05 \x01(\t\x12\x37\n\x07\x64isable\x18\x06 \x01(\x0e\x32&.bilibili.dynamic.gateway.DisableState\"\x8d\x02\n\rAdditionalPGC\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12:\n\x06\x62utton\x18\x07 \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionalButton\x12\x11\n\thead_icon\x18\x08 \x01(\t\x12\x33\n\x05style\x18\t \x01(\x0e\x32$.bilibili.dynamic.gateway.ImageStyle\x12\x0c\n\x04type\x18\n \x01(\t\"\x9e\x01\n\x10\x43\x61rdVideoDynList\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x08\"d\n\x13\x43\x61rdVideoFollowList\x12\x15\n\rview_all_link\x18\x01 \x01(\t\x12\x36\n\x04list\x18\x02 \x03(\x0b\x32(.bilibili.dynamic.gateway.FollowListItem\"\xa0\x02\n\x0f\x43\x61rdVideoUpList\x12\r\n\x05title\x18\x01 \x01(\t\x12\x32\n\x04list\x18\x02 \x03(\x0b\x32$.bilibili.dynamic.gateway.UpListItem\x12\x11\n\tfootprint\x18\x03 \x01(\t\x12\x15\n\rshow_live_num\x18\x04 \x01(\x05\x12=\n\nmore_label\x18\x05 \x01(\x0b\x32).bilibili.dynamic.gateway.UpListMoreLabel\x12\x14\n\x0ctitle_switch\x18\x06 \x01(\x05\x12\x17\n\x0fshow_more_label\x18\x07 \x01(\x08\x12\x18\n\x10show_in_personal\x18\x08 \x01(\x08\x12\x18\n\x10show_more_button\x18\t \x01(\x08\"G\n\x0b\x43mtShowItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0f\n\x07\x63omment\x18\x04 \x01(\t\"P\n\x0b\x44\x65\x63oCardFan\x12\x0e\n\x06is_fan\x18\x01 \x01(\x05\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12\x12\n\nnumber_str\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\"r\n\x0c\x44\x65\x63orateCard\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x32\n\x03\x66\x61n\x18\x04 \x01(\x0b\x32%.bilibili.dynamic.gateway.DecoCardFan\"\xa6\x02\n\x0b\x44\x65scription\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x30\n\x04type\x18\x02 \x01(\x0e\x32\".bilibili.dynamic.gateway.DescType\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x37\n\nemoji_type\x18\x04 \x01(\x0e\x32#.bilibili.dynamic.gateway.EmojiType\x12\x12\n\ngoods_type\x18\x05 \x01(\t\x12\x10\n\x08icon_url\x18\x06 \x01(\t\x12\x11\n\ticon_name\x18\x07 \x01(\t\x12\x0b\n\x03rid\x18\x08 \x01(\t\x12\x38\n\x05goods\x18\t \x01(\x0b\x32).bilibili.dynamic.gateway.ModuleDescGoods\x12\x11\n\torig_text\x18\n \x01(\t\":\n\tDimension\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"`\n\x1c\x44ynAdditionCommonFollowReply\x12@\n\x06status\x18\x01 \x01(\x0e\x32\x30.bilibili.dynamic.gateway.AdditionalButtonStatus\"\x81\x01\n\x1a\x44ynAdditionCommonFollowReq\x12@\n\x06status\x18\x01 \x01(\x0e\x32\x30.bilibili.dynamic.gateway.AdditionalButtonStatus\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\t\x12\x11\n\tcard_type\x18\x03 \x01(\t\"\xb7\x01\n\x13\x44ynAllPersonalReply\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\x12\x34\n\x08relation\x18\x05 \x01(\x0b\x32\".bilibili.dynamic.gateway.Relation\"\x86\x02\n\x11\x44ynAllPersonalReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x12\n\nis_preload\x18\x04 \x01(\x05\x12=\n\rplayurl_param\x18\x05 \x01(\x0b\x32&.bilibili.dynamic.gateway.PlayurlParam\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x11\n\tfootprint\x18\x07 \x01(\t\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x39\n\x0bplayer_args\x18\t \x01(\x0b\x32$.bilibili.dynamic.gateway.PlayerArgs\"\xf5\x01\n\x0b\x44ynAllReply\x12;\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32%.bilibili.dynamic.gateway.DynamicList\x12:\n\x07up_list\x18\x02 \x01(\x0b\x32).bilibili.dynamic.gateway.CardVideoUpList\x12\x37\n\ntopic_list\x18\x03 \x01(\x0b\x32#.bilibili.dynamic.gateway.TopicList\x12\x34\n\x08unfollow\x18\x04 \x01(\x0b\x32\".bilibili.dynamic.gateway.Unfollow\"\xb9\x03\n\tDynAllReq\x12\x17\n\x0fupdate_baseline\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x37\n\x0crefresh_type\x18\x04 \x01(\x0e\x32!.bilibili.dynamic.gateway.Refresh\x12=\n\rplayurl_param\x18\x05 \x01(\x0b\x32&.bilibili.dynamic.gateway.PlayurlParam\x12\x17\n\x0f\x61ssist_baseline\x18\x06 \x01(\t\x12\x12\n\nlocal_time\x18\x07 \x01(\x05\x12>\n\x0ercmd_ups_param\x18\x08 \x01(\x0b\x32&.bilibili.dynamic.gateway.RcmdUPsParam\x12\x33\n\x08\x61\x64_param\x18\t \x01(\x0b\x32!.bilibili.dynamic.gateway.AdParam\x12\x12\n\ncold_start\x18\n \x01(\x05\x12\x0c\n\x04\x66rom\x18\x0b \x01(\t\x12\x39\n\x0bplayer_args\x18\x0c \x01(\x0b\x32$.bilibili.dynamic.gateway.PlayerArgs\"N\n\x12\x44ynAllUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\x12\x11\n\tfootprint\x18\x03 \x01(\t\"E\n\x0e\x44ynDetailReply\x12\x33\n\x04item\x18\x01 \x01(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\"\xb2\x01\n\rDynDetailsReq\x12\x13\n\x0b\x64ynamic_ids\x18\x01 \x01(\t\x12=\n\rplayurl_param\x18\x02 \x01(\x0b\x32&.bilibili.dynamic.gateway.PlayurlParam\x12\x12\n\nlocal_time\x18\x03 \x01(\x05\x12\x39\n\x0bplayer_args\x18\x04 \x01(\x0b\x32$.bilibili.dynamic.gateway.PlayerArgs\"G\n\x10\x44ynFakeCardReply\x12\x33\n\x04item\x18\x01 \x01(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\"!\n\x0e\x44ynFakeCardReq\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"\xe1\x01\n\x19\x44ynMixUpListViewMoreReply\x12\x36\n\x05items\x18\x01 \x03(\x0b\x32\'.bilibili.dynamic.gateway.MixUpListItem\x12\x1b\n\x13search_default_text\x18\x02 \x01(\t\x12\x36\n\nsort_types\x18\x03 \x03(\x0b\x32\".bilibili.dynamic.gateway.SortType\x12\x1c\n\x14show_more_sort_types\x18\x04 \x01(\x08\x12\x19\n\x11\x64\x65\x66\x61ult_sort_type\x18\x05 \x01(\x05\",\n\x17\x44ynMixUpListViewMoreReq\x12\x11\n\tsort_type\x18\x01 \x01(\x05\"N\n\x16\x44ynRcmdUpExchangeReply\x12\x34\n\x08unfollow\x18\x01 \x01(\x0b\x32\".bilibili.dynamic.gateway.Unfollow\"D\n\x14\x44ynRcmdUpExchangeReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\tdislikeTs\x18\x02 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\"|\n\x0b\x44ynThumbReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x03 \x01(\x03\x12\x0b\n\x03rid\x18\x04 \x01(\t\x12\x31\n\x04type\x18\x05 \x01(\x0e\x32#.bilibili.dynamic.gateway.ThumbType\"\xb9\x01\n\x15\x44ynVideoPersonalReply\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\x12\x34\n\x08relation\x18\x05 \x01(\x0b\x32\".bilibili.dynamic.gateway.Relation\"\x88\x02\n\x13\x44ynVideoPersonalReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x12\n\nis_preload\x18\x04 \x01(\x05\x12=\n\rplayurl_param\x18\x05 \x01(\x0b\x32&.bilibili.dynamic.gateway.PlayurlParam\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x11\n\tfootprint\x18\x07 \x01(\t\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x39\n\x0bplayer_args\x18\t \x01(\x0b\x32$.bilibili.dynamic.gateway.PlayerArgs\"\xdd\x01\n\rDynVideoReply\x12@\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32*.bilibili.dynamic.gateway.CardVideoDynList\x12@\n\rvideo_up_list\x18\x02 \x01(\x0b\x32).bilibili.dynamic.gateway.CardVideoUpList\x12H\n\x11video_follow_list\x18\x03 \x01(\x0b\x32-.bilibili.dynamic.gateway.CardVideoFollowList\"\xb2\x02\n\x0b\x44ynVideoReq\x12\x17\n\x0fupdate_baseline\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x37\n\x0crefresh_type\x18\x04 \x01(\x0e\x32!.bilibili.dynamic.gateway.Refresh\x12=\n\rplayurl_param\x18\x05 \x01(\x0b\x32&.bilibili.dynamic.gateway.PlayurlParam\x12\x17\n\x0f\x61ssist_baseline\x18\x06 \x01(\t\x12\x12\n\nlocal_time\x18\x07 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x39\n\x0bplayer_args\x18\t \x01(\x0b\x32$.bilibili.dynamic.gateway.PlayerArgs\"P\n\x14\x44ynVideoUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\x12\x11\n\tfootprint\x18\x03 \x01(\t\"T\n\x0c\x44ynVoteReply\x12\x35\n\x04item\x18\x01 \x01(\x0b\x32\'.bilibili.dynamic.gateway.AdditionVote2\x12\r\n\x05toast\x18\x02 \x01(\t\"\x85\x01\n\nDynVoteReq\x12\x0f\n\x07vote_id\x18\x01 \x01(\x03\x12\r\n\x05votes\x18\x02 \x03(\x03\x12\x34\n\x06status\x18\x03 \x01(\x0e\x32$.bilibili.dynamic.gateway.VoteStatus\x12\x12\n\ndynamic_id\x18\x04 \x01(\t\x12\r\n\x05share\x18\x05 \x01(\x08\"\xf8\x01\n\x0b\x44ynamicItem\x12\x38\n\tcard_type\x18\x01 \x01(\x0e\x32%.bilibili.dynamic.gateway.DynamicType\x12\x38\n\titem_type\x18\x02 \x01(\x0e\x32%.bilibili.dynamic.gateway.DynamicType\x12\x31\n\x07modules\x18\x03 \x03(\x0b\x32 .bilibili.dynamic.gateway.Module\x12\x30\n\x06\x65xtend\x18\x04 \x01(\x0b\x32 .bilibili.dynamic.gateway.Extend\x12\x10\n\x08has_fold\x18\x05 \x01(\x05\"\x99\x01\n\x0b\x44ynamicList\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x08\"\xe3\x01\n\rExtInfoCommon\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\x12\x35\n\x04type\x18\x05 \x01(\x0e\x32\'.bilibili.dynamic.gateway.DynExtendType\x12\x12\n\nsub_module\x18\x06 \x01(\t\x12\x13\n\x0b\x61\x63tion_text\x18\x07 \x01(\t\x12\x12\n\naction_url\x18\x08 \x01(\t\x12\x0b\n\x03rid\x18\t \x01(\x03\x12\x15\n\ris_show_light\x18\n \x01(\x08\"7\n\x0b\x45xtInfoGame\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"6\n\nExtInfoHot\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"H\n\nExtInfoLBS\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\"A\n\nExtInfoOGV\x12\x33\n\x08info_ogv\x18\x01 \x03(\x0b\x32!.bilibili.dynamic.gateway.InfoOGV\"8\n\x0c\x45xtInfoTopic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"\x98\x04\n\x06\x45xtend\x12\x12\n\ndyn_id_str\x18\x01 \x01(\t\x12\x13\n\x0b\x62usiness_id\x18\x02 \x01(\t\x12\x17\n\x0forig_dyn_id_str\x18\x03 \x01(\t\x12\x11\n\torig_name\x18\x04 \x01(\t\x12\x14\n\x0corig_img_url\x18\x05 \x01(\t\x12\x38\n\torig_desc\x18\x06 \x03(\x0b\x32%.bilibili.dynamic.gateway.Description\x12\x33\n\x04\x64\x65sc\x18\x07 \x03(\x0b\x32%.bilibili.dynamic.gateway.Description\x12<\n\rorig_dyn_type\x18\x08 \x01(\x0e\x32%.bilibili.dynamic.gateway.DynamicType\x12\x12\n\nshare_type\x18\t \x01(\t\x12\x13\n\x0bshare_scene\x18\n \x01(\t\x12\x15\n\ris_fast_share\x18\x0b \x01(\x08\x12\x0e\n\x06r_type\x18\x0c \x01(\x05\x12\x10\n\x08\x64yn_type\x18\r \x01(\x03\x12\x0b\n\x03uid\x18\x0e \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x0f \x01(\t\x12,\n\x0esource_content\x18\x10 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\torig_face\x18\x11 \x01(\t\x12\x34\n\x05reply\x18\x12 \x01(\x0b\x32%.bilibili.dynamic.gateway.ExtendReply\"V\n\x0b\x45xtendReply\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12:\n\x06params\x18\x02 \x03(\x0b\x32*.bilibili.dynamic.gateway.ExtendReplyParam\".\n\x10\x45xtendReplyParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x9f\x01\n\x0e\x46ollowListItem\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12/\n\x06new_ep\x18\x05 \x01(\x0b\x32\x1f.bilibili.dynamic.gateway.NewEP\x12\x11\n\tsub_title\x18\x06 \x01(\t\x12\x0b\n\x03pos\x18\x07 \x01(\x03\"\x82\x02\n\tGoodsItem\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x1b\n\x13schema_package_name\x18\x02 \x01(\t\x12\x13\n\x0bsource_type\x18\x03 \x01(\x05\x12\x10\n\x08jump_url\x18\x04 \x01(\t\x12\x11\n\tjump_desc\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\r\n\x05\x62rief\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\t\x12\x0f\n\x07item_id\x18\t \x01(\x03\x12\x12\n\nschema_url\x18\n \x01(\t\x12\x17\n\x0fopen_white_list\x18\x0b \x03(\t\x12\x13\n\x0buser_web_v2\x18\x0c \x01(\x08\x12\x0f\n\x07\x61\x64_mark\x18\r \x01(\t\"_\n\rHighlightText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12@\n\ntext_style\x18\x02 \x01(\x0e\x32,.bilibili.dynamic.gateway.HighlightTextStyle\"G\n\x07InfoOGV\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x12\n\nsub_module\x18\x04 \x01(\t\"\xb8\x01\n\x0fInteractionItem\x12:\n\ticon_type\x18\x01 \x01(\x0e\x32\'.bilibili.dynamic.gateway.LocalIconType\x12\x33\n\x04\x64\x65sc\x18\x02 \x03(\x0b\x32%.bilibili.dynamic.gateway.Description\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x12\n\ndynamic_id\x18\x04 \x01(\t\x12\x13\n\x0b\x63omment_mid\x18\x06 \x01(\x03\"O\n\rLikeAnimation\x12\r\n\x05\x62\x65gin\x18\x01 \x01(\t\x12\x0c\n\x04proc\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x14\n\x0clike_icon_id\x18\x04 \x01(\x03\"W\n\x08LikeInfo\x12:\n\tanimation\x18\x01 \x01(\x0b\x32\'.bilibili.dynamic.gateway.LikeAnimation\x12\x0f\n\x07is_like\x18\x02 \x01(\x08\"3\n\x08LikeUser\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"c\n\x08LiveInfo\x12\x11\n\tis_living\x18\x01 \x01(\x05\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x37\n\nlive_state\x18\x03 \x01(\x0e\x32#.bilibili.dynamic.gateway.LiveState\"X\n\tMatchTeam\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\x12\x13\n\x0bnight_color\x18\x05 \x01(\t\"\x8b\x01\n\x0cMdlDynApplet\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x11\n\tsub_title\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\r\n\x05label\x18\x08 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\t \x01(\t\"\xe3\x05\n\rMdlDynArchive\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0c\n\x04\x61vid\x18\x07 \x01(\x03\x12\x0b\n\x03\x63id\x18\x08 \x01(\x03\x12\x37\n\nmedia_type\x18\t \x01(\x0e\x32#.bilibili.dynamic.gateway.MediaType\x12\x36\n\tdimension\x18\n \x01(\x0b\x32#.bilibili.dynamic.gateway.Dimension\x12\x33\n\x05\x62\x61\x64ge\x18\x0b \x03(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x0c \x01(\x08\x12\x32\n\x05stype\x18\r \x01(\x0e\x32#.bilibili.dynamic.gateway.VideoType\x12\r\n\x05isPGC\x18\x0e \x01(\x08\x12\x11\n\tinlineURL\x18\x0f \x01(\t\x12\x11\n\tEpisodeId\x18\x10 \x01(\x03\x12\x0f\n\x07SubType\x18\x11 \x01(\x05\x12\x13\n\x0bPgcSeasonId\x18\x12 \x01(\x03\x12\x11\n\tplay_icon\x18\x13 \x01(\t\x12\x10\n\x08\x64uration\x18\x14 \x01(\x03\x12\x10\n\x08jump_url\x18\x15 \x01(\t\x12\x12\n\nis_preview\x18\x16 \x01(\x08\x12<\n\x0e\x62\x61\x64ge_category\x18\x17 \x03(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x12\n\nis_feature\x18\x18 \x01(\x08\x12;\n\x0creserve_type\x18\x19 \x01(\x0e\x32%.bilibili.dynamic.gateway.ReserveType\x12\x0c\n\x04\x62vid\x18\x1a \x01(\t\x12\x0c\n\x04view\x18\x1b \x01(\x05\"x\n\rMdlDynArticle\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x0e\n\x06\x63overs\x18\x05 \x03(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x12\n\ntemplateID\x18\x07 \x01(\x05\"\xf6\x01\n\x0cMdlDynCommon\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x0f\n\x07\x62izType\x18\x07 \x01(\x05\x12\x10\n\x08sketchID\x18\x08 \x01(\x03\x12\x39\n\x05style\x18\t \x01(\x0e\x32*.bilibili.dynamic.gateway.MdlDynCommonType\x12\x33\n\x05\x62\x61\x64ge\x18\n \x03(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\"\xa4\x01\n\x0fMdlDynCourBatch\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0e\n\x06text_2\x18\x05 \x01(\t\x12\x33\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x11\n\tplay_icon\x18\x07 \x01(\t\"\xa3\x01\n\x10MdlDynCourSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12\x33\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x11\n\tplay_icon\x18\x07 \x01(\t\"^\n\nMdlDynDraw\x12\x37\n\x05items\x18\x01 \x03(\x0b\x32(.bilibili.dynamic.gateway.MdlDynDrawItem\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x03\"\x81\x01\n\x0eMdlDynDrawItem\x12\x0b\n\x03src\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x0c\n\x04size\x18\x04 \x01(\x02\x12\x35\n\x04tags\x18\x05 \x03(\x0b\x32\'.bilibili.dynamic.gateway.MdlDynDrawTag\"\x85\x01\n\rMdlDynDrawTag\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.bilibili.dynamic.gateway.MdlDynDrawTagType\x12\x39\n\x04item\x18\x02 \x01(\x0b\x32+.bilibili.dynamic.gateway.MdlDynDrawTagItem\"\xb5\x01\n\x11MdlDynDrawTagItem\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\t\n\x01x\x18\x03 \x01(\x03\x12\t\n\x01y\x18\x04 \x01(\x03\x12\x13\n\x0borientation\x18\x05 \x01(\x05\x12\x0e\n\x06source\x18\x06 \x01(\x05\x12\x0f\n\x07item_id\x18\x07 \x01(\x03\x12\x0b\n\x03mid\x18\x08 \x01(\x03\x12\x0b\n\x03tid\x18\t \x01(\x03\x12\x0b\n\x03poi\x18\n \x01(\t\x12\x12\n\nschema_url\x18\x0b \x01(\t\"S\n\rMdlDynForward\x12\x33\n\x04item\x18\x01 \x01(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\x12\r\n\x05rtype\x18\x02 \x01(\x05\"\x99\x02\n\nMdlDynLive\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x13\n\x0b\x63over_label\x18\x05 \x01(\t\x12\x14\n\x0c\x63over_label2\x18\x06 \x01(\t\x12\x37\n\nlive_state\x18\x07 \x01(\x0e\x32#.bilibili.dynamic.gateway.LiveState\x12\x33\n\x05\x62\x61\x64ge\x18\x08 \x01(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12;\n\x0creserve_type\x18\t \x01(\x0e\x32%.bilibili.dynamic.gateway.ReserveType\"^\n\x0eMdlDynLiveRcmd\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12;\n\x0creserve_type\x18\x02 \x01(\x0e\x32%.bilibili.dynamic.gateway.ReserveType\"\xa4\x01\n\x0fMdlDynMedialist\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x11\n\tsub_title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x12\n\ncover_type\x18\x06 \x01(\x05\x12\x33\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\"r\n\x0bMdlDynMusic\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05up_id\x18\x03 \x01(\x03\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x0e\n\x06label1\x18\x06 \x01(\t\x12\r\n\x05upper\x18\x07 \x01(\t\"\x86\x05\n\tMdlDynPGC\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x11\n\tseason_id\x18\x08 \x01(\x03\x12\x0c\n\x04\x65pid\x18\t \x01(\x03\x12\x0b\n\x03\x61id\x18\n \x01(\x03\x12\x37\n\nmedia_type\x18\x0b \x01(\x0e\x32#.bilibili.dynamic.gateway.MediaType\x12\x38\n\x08sub_type\x18\x0c \x01(\x0e\x32&.bilibili.dynamic.gateway.VideoSubType\x12\x12\n\nis_preview\x18\r \x01(\x08\x12\x36\n\tdimension\x18\x0e \x01(\x0b\x32#.bilibili.dynamic.gateway.Dimension\x12\x33\n\x05\x62\x61\x64ge\x18\x0f \x03(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x10 \x01(\x08\x12\x33\n\x06season\x18\x11 \x01(\x0b\x32#.bilibili.dynamic.gateway.PGCSeason\x12\x11\n\tplay_icon\x18\x12 \x01(\t\x12\x10\n\x08\x64uration\x18\x13 \x01(\x03\x12\x10\n\x08jump_url\x18\x14 \x01(\t\x12<\n\x0e\x62\x61\x64ge_category\x18\x15 \x03(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x12\n\nis_feature\x18\x16 \x01(\x08\"\xaf\x01\n\x12MdlDynSubscription\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05\x61\x64_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x10\n\x08\x61\x64_title\x18\x06 \x01(\t\x12\x33\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x0c\n\x04tips\x18\x08 \x01(\t\"\xf1\x01\n\x15MdlDynSubscriptionNew\x12\x43\n\x05style\x18\x01 \x01(\x0e\x32\x34.bilibili.dynamic.gateway.MdlDynSubscriptionNewStyle\x12H\n\x10\x64yn_subscription\x18\x02 \x01(\x0b\x32,.bilibili.dynamic.gateway.MdlDynSubscriptionH\x00\x12\x41\n\rdyn_live_rcmd\x18\x03 \x01(\x0b\x32(.bilibili.dynamic.gateway.MdlDynLiveRcmdH\x00\x42\x06\n\x04item\"\xc8\x02\n\x0fMdlDynUGCSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\x03\x12\x11\n\tinlineURL\x18\x08 \x01(\t\x12\x10\n\x08\x63\x61n_play\x18\t \x01(\x08\x12\x11\n\tplay_icon\x18\n \x01(\t\x12\x0c\n\x04\x61vid\x18\x0b \x01(\x03\x12\x0b\n\x03\x63id\x18\x0c \x01(\x03\x12\x36\n\tdimension\x18\r \x01(\x0b\x32#.bilibili.dynamic.gateway.Dimension\x12\x10\n\x08\x64uration\x18\x0e \x01(\x03\x12\x10\n\x08jump_url\x18\x0f \x01(\t\"\xcb\x02\n\rMixUpListItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x19\n\x11special_attention\x18\x02 \x01(\x05\x12\x14\n\x0creddot_state\x18\x03 \x01(\x05\x12>\n\tlive_info\x18\x04 \x01(\x0b\x32+.bilibili.dynamic.gateway.MixUpListLiveItem\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x06 \x01(\t\x12:\n\x08official\x18\x07 \x01(\x0b\x32(.bilibili.dynamic.gateway.OfficialVerify\x12.\n\x03vip\x18\x08 \x01(\x0b\x32!.bilibili.dynamic.gateway.VipInfo\x12\x34\n\x08relation\x18\t \x01(\x0b\x32\".bilibili.dynamic.gateway.Relation\"A\n\x11MixUpListLiveItem\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\x90\x0b\n\x06Module\x12<\n\x0bmodule_type\x18\x01 \x01(\x0e\x32\'.bilibili.dynamic.gateway.DynModuleType\x12?\n\rmodule_author\x18\x02 \x01(\x0b\x32&.bilibili.dynamic.gateway.ModuleAuthorH\x00\x12\x41\n\x0emodule_dispute\x18\x03 \x01(\x0b\x32\'.bilibili.dynamic.gateway.ModuleDisputeH\x00\x12;\n\x0bmodule_desc\x18\x04 \x01(\x0b\x32$.bilibili.dynamic.gateway.ModuleDescH\x00\x12\x41\n\x0emodule_dynamic\x18\x05 \x01(\x0b\x32\'.bilibili.dynamic.gateway.ModuleDynamicH\x00\x12\x43\n\x0fmodule_likeUser\x18\x06 \x01(\x0b\x32(.bilibili.dynamic.gateway.ModuleLikeUserH\x00\x12?\n\rmodule_extend\x18\x07 \x01(\x0b\x32&.bilibili.dynamic.gateway.ModuleExtendH\x00\x12G\n\x11module_additional\x18\x08 \x01(\x0b\x32*.bilibili.dynamic.gateway.ModuleAdditionalH\x00\x12;\n\x0bmodule_stat\x18\t \x01(\x0b\x32$.bilibili.dynamic.gateway.ModuleStatH\x00\x12;\n\x0bmodule_fold\x18\n \x01(\x0b\x32$.bilibili.dynamic.gateway.ModuleFoldH\x00\x12\x41\n\x0emodule_comment\x18\x0b \x01(\x0b\x32\'.bilibili.dynamic.gateway.ModuleCommentH\x00\x12I\n\x12module_interaction\x18\x0c \x01(\x0b\x32+.bilibili.dynamic.gateway.ModuleInteractionH\x00\x12N\n\x15module_author_forward\x18\r \x01(\x0b\x32-.bilibili.dynamic.gateway.ModuleAuthorForwardH\x00\x12\x37\n\tmodule_ad\x18\x0e \x01(\x0b\x32\".bilibili.dynamic.gateway.ModuleAdH\x00\x12?\n\rmodule_banner\x18\x0f \x01(\x0b\x32&.bilibili.dynamic.gateway.ModuleBannerH\x00\x12\x44\n\x10module_item_null\x18\x10 \x01(\x0b\x32(.bilibili.dynamic.gateway.ModuleItemNullH\x00\x12\x46\n\x11module_share_info\x18\x11 \x01(\x0b\x32).bilibili.dynamic.gateway.ModuleShareInfoH\x00\x12\x45\n\x10module_recommend\x18\x12 \x01(\x0b\x32).bilibili.dynamic.gateway.ModuleRecommendH\x00\x12\x39\n\nmodule_top\x18\x13 \x01(\x0b\x32#.bilibili.dynamic.gateway.ModuleTopH\x00\x12?\n\rmodule_buttom\x18\x14 \x01(\x0b\x32&.bilibili.dynamic.gateway.ModuleButtomH\x00\x12\x43\n\x13module_stat_forward\x18\x15 \x01(\x0b\x32$.bilibili.dynamic.gateway.ModuleStatH\x00\x42\r\n\x0bmodule_item\"w\n\x08ModuleAd\x12,\n\x0esource_content\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12=\n\rmodule_author\x18\x02 \x01(\x0b\x32&.bilibili.dynamic.gateway.ModuleAuthor\"\xa5\x04\n\x10ModuleAdditional\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.bilibili.dynamic.gateway.AdditionalType\x12\x36\n\x03pgc\x18\x02 \x01(\x0b\x32\'.bilibili.dynamic.gateway.AdditionalPGCH\x00\x12\x38\n\x05goods\x18\x03 \x01(\x0b\x32\'.bilibili.dynamic.gateway.AdditionGoodsH\x00\x12\x36\n\x04vote\x18\x04 \x01(\x0b\x32&.bilibili.dynamic.gateway.AdditionVoteH\x00\x12:\n\x06\x63ommon\x18\x05 \x01(\x0b\x32(.bilibili.dynamic.gateway.AdditionCommonH\x00\x12:\n\x06\x65sport\x18\x06 \x01(\x0b\x32(.bilibili.dynamic.gateway.AdditionEsportH\x00\x12\x38\n\x05vote2\x18\x08 \x01(\x0b\x32\'.bilibili.dynamic.gateway.AdditionVote2H\x00\x12\x34\n\x03ugc\x18\t \x01(\x0b\x32%.bilibili.dynamic.gateway.AdditionUgcH\x00\x12\x32\n\x02up\x18\n \x01(\x0b\x32$.bilibili.dynamic.gateway.AdditionUPH\x00\x12\x0b\n\x03rid\x18\x07 \x01(\x03\x42\x06\n\x04item\"\xf6\x03\n\x0cModuleAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x02 \x01(\t\x12\x32\n\x06\x61uthor\x18\x03 \x01(\x0b\x32\".bilibili.dynamic.gateway.UserInfo\x12=\n\rdecorate_card\x18\x04 \x01(\x0b\x32&.bilibili.dynamic.gateway.DecorateCard\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x39\n\x07tp_list\x18\x06 \x03(\x0b\x32(.bilibili.dynamic.gateway.ThreePointItem\x12\x43\n\nbadge_type\x18\x07 \x01(\x0e\x32/.bilibili.dynamic.gateway.ModuleAuthorBadgeType\x12G\n\x0c\x62\x61\x64ge_button\x18\x08 \x01(\x0b\x32\x31.bilibili.dynamic.gateway.ModuleAuthorBadgeButton\x12\x0e\n\x06\x61ttend\x18\t \x01(\x05\x12\x34\n\x08relation\x18\n \x01(\x0b\x32\".bilibili.dynamic.gateway.Relation\x12\x30\n\x06weight\x18\x0b \x01(\x0b\x32 .bilibili.dynamic.gateway.Weight\"Q\n\x17ModuleAuthorBadgeButton\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\x05\x12\n\n\x02id\x18\x04 \x01(\x03\"\xa4\x02\n\x13ModuleAuthorForward\x12\x41\n\x05title\x18\x01 \x03(\x0b\x32\x32.bilibili.dynamic.gateway.ModuleAuthorForwardTitle\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x04 \x01(\t\x12\x13\n\x0bshow_follow\x18\x05 \x01(\x08\x12\x10\n\x08\x66\x61\x63\x65_url\x18\x06 \x01(\t\x12\x34\n\x08relation\x18\x07 \x01(\x0b\x32\".bilibili.dynamic.gateway.Relation\x12\x39\n\x07tp_list\x18\x08 \x03(\x0b\x32(.bilibili.dynamic.gateway.ThreePointItem\"5\n\x18ModuleAuthorForwardTitle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\xc7\x01\n\x0cModuleBanner\x12\r\n\x05title\x18\x01 \x01(\t\x12\x38\n\x04type\x18\x02 \x01(\x0e\x32*.bilibili.dynamic.gateway.ModuleBannerType\x12:\n\x04user\x18\x03 \x01(\x0b\x32*.bilibili.dynamic.gateway.ModuleBannerUserH\x00\x12\x14\n\x0c\x64islike_text\x18\x04 \x01(\t\x12\x14\n\x0c\x64islike_icon\x18\x05 \x01(\tB\x06\n\x04item\"P\n\x10ModuleBannerUser\x12<\n\x04list\x18\x01 \x03(\x0b\x32..bilibili.dynamic.gateway.ModuleBannerUserItem\"\xbc\x02\n\x14ModuleBannerUserItem\x12\x0c\n\x04\x66\x61\x63\x65\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x37\n\nlive_state\x18\x04 \x01(\x0e\x32#.bilibili.dynamic.gateway.LiveState\x12:\n\x08official\x18\x05 \x01(\x0b\x32(.bilibili.dynamic.gateway.OfficialVerify\x12.\n\x03vip\x18\x06 \x01(\x0b\x32!.bilibili.dynamic.gateway.VipInfo\x12\r\n\x05label\x18\x07 \x01(\t\x12:\n\x06\x62utton\x18\x08 \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionalButton\x12\x0b\n\x03uri\x18\t \x01(\t\"I\n\x0cModuleButtom\x12\x39\n\x0bmodule_stat\x18\x01 \x01(\x0b\x32$.bilibili.dynamic.gateway.ModuleStat\"K\n\rModuleComment\x12:\n\x0b\x63mtShowItem\x18\x01 \x03(\x0b\x32%.bilibili.dynamic.gateway.CmtShowItem\"a\n\nModuleDesc\x12\x33\n\x04\x64\x65sc\x18\x01 \x03(\x0b\x32%.bilibili.dynamic.gateway.Description\x12\x10\n\x08jump_uri\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\xb9\x01\n\x0fModuleDescGoods\x12\x13\n\x0bsource_type\x18\x01 \x01(\x05\x12\x10\n\x08jump_url\x18\x02 \x01(\t\x12\x12\n\nschema_url\x18\x03 \x01(\t\x12\x0f\n\x07item_id\x18\x04 \x01(\x03\x12\x17\n\x0fopen_white_list\x18\x05 \x03(\t\x12\x13\n\x0buser_web_v2\x18\x06 \x01(\x08\x12\x0f\n\x07\x61\x64_mark\x18\x07 \x01(\t\x12\x1b\n\x13schema_package_name\x18\x08 \x01(\t\"9\n\rModuleDispute\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xf7\x08\n\rModuleDynamic\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.bilibili.dynamic.gateway.ModuleDynamicType\x12>\n\x0b\x64yn_archive\x18\x02 \x01(\x0b\x32\'.bilibili.dynamic.gateway.MdlDynArchiveH\x00\x12\x36\n\x07\x64yn_pgc\x18\x03 \x01(\x0b\x32#.bilibili.dynamic.gateway.MdlDynPGCH\x00\x12\x45\n\x0f\x64yn_cour_season\x18\x04 \x01(\x0b\x32*.bilibili.dynamic.gateway.MdlDynCourSeasonH\x00\x12\x43\n\x0e\x64yn_cour_batch\x18\x05 \x01(\x0b\x32).bilibili.dynamic.gateway.MdlDynCourBatchH\x00\x12>\n\x0b\x64yn_forward\x18\x06 \x01(\x0b\x32\'.bilibili.dynamic.gateway.MdlDynForwardH\x00\x12\x38\n\x08\x64yn_draw\x18\x07 \x01(\x0b\x32$.bilibili.dynamic.gateway.MdlDynDrawH\x00\x12>\n\x0b\x64yn_article\x18\x08 \x01(\x0b\x32\'.bilibili.dynamic.gateway.MdlDynArticleH\x00\x12:\n\tdyn_music\x18\t \x01(\x0b\x32%.bilibili.dynamic.gateway.MdlDynMusicH\x00\x12<\n\ndyn_common\x18\n \x01(\x0b\x32&.bilibili.dynamic.gateway.MdlDynCommonH\x00\x12?\n\x0f\x64yn_common_live\x18\x0b \x01(\x0b\x32$.bilibili.dynamic.gateway.MdlDynLiveH\x00\x12\x42\n\rdyn_medialist\x18\x0c \x01(\x0b\x32).bilibili.dynamic.gateway.MdlDynMedialistH\x00\x12<\n\ndyn_applet\x18\r \x01(\x0b\x32&.bilibili.dynamic.gateway.MdlDynAppletH\x00\x12H\n\x10\x64yn_subscription\x18\x0e \x01(\x0b\x32,.bilibili.dynamic.gateway.MdlDynSubscriptionH\x00\x12\x41\n\rdyn_live_rcmd\x18\x0f \x01(\x0b\x32(.bilibili.dynamic.gateway.MdlDynLiveRcmdH\x00\x12\x43\n\x0e\x64yn_ugc_season\x18\x10 \x01(\x0b\x32).bilibili.dynamic.gateway.MdlDynUGCSeasonH\x00\x12O\n\x14\x64yn_subscription_new\x18\x11 \x01(\x0b\x32/.bilibili.dynamic.gateway.MdlDynSubscriptionNewH\x00\x42\r\n\x0bmodule_item\"W\n\x0cModuleExtend\x12:\n\x06\x65xtend\x18\x01 \x03(\x0b\x32*.bilibili.dynamic.gateway.ModuleExtendItem\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xd3\x03\n\x10ModuleExtendItem\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.bilibili.dynamic.gateway.DynExtendType\x12@\n\x0e\x65xt_info_topic\x18\x02 \x01(\x0b\x32&.bilibili.dynamic.gateway.ExtInfoTopicH\x00\x12<\n\x0c\x65xt_info_lbs\x18\x03 \x01(\x0b\x32$.bilibili.dynamic.gateway.ExtInfoLBSH\x00\x12<\n\x0c\x65xt_info_hot\x18\x04 \x01(\x0b\x32$.bilibili.dynamic.gateway.ExtInfoHotH\x00\x12>\n\rext_info_game\x18\x05 \x01(\x0b\x32%.bilibili.dynamic.gateway.ExtInfoGameH\x00\x12\x42\n\x0f\x65xt_info_common\x18\x06 \x01(\x0b\x32\'.bilibili.dynamic.gateway.ExtInfoCommonH\x00\x12<\n\x0c\x65xt_info_ogv\x18\x07 \x01(\x0b\x32$.bilibili.dynamic.gateway.ExtInfoOGVH\x00\x42\x08\n\x06\x65xtend\"\x9b\x01\n\nModuleFold\x12\x35\n\tfold_type\x18\x01 \x01(\x0e\x32\".bilibili.dynamic.gateway.FoldType\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08\x66old_ids\x18\x03 \x01(\t\x12\x36\n\nfold_users\x18\x04 \x03(\x0b\x32\".bilibili.dynamic.gateway.UserInfo\"X\n\x11ModuleInteraction\x12\x43\n\x10interaction_item\x18\x01 \x03(\x0b\x32).bilibili.dynamic.gateway.InteractionItem\",\n\x0eModuleItemNull\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"^\n\x0eModuleLikeUser\x12\x36\n\nlike_users\x18\x01 \x03(\x0b\x32\".bilibili.dynamic.gateway.LikeUser\x12\x14\n\x0c\x64isplay_text\x18\x02 \x01(\t\"\x86\x01\n\x0fModuleRecommend\x12\x14\n\x0cmodule_title\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x10\n\x08jump_url\x18\x05 \x01(\t\x12 \n\x02\x61\x64\x18\x06 \x03(\x0b\x32\x14.google.protobuf.Any\"\x90\x01\n\x0fModuleShareInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12>\n\x0eshare_channels\x18\x02 \x03(\x0b\x32&.bilibili.dynamic.gateway.ShareChannel\x12\x14\n\x0cshare_origin\x18\x03 \x01(\t\x12\x0b\n\x03oid\x18\x04 \x01(\t\x12\x0b\n\x03sid\x18\x05 \x01(\t\"\xdd\x01\n\nModuleStat\x12\x0e\n\x06repost\x18\x01 \x01(\x03\x12\x0c\n\x04like\x18\x02 \x01(\x03\x12\r\n\x05reply\x18\x03 \x01(\x03\x12\x35\n\tlike_info\x18\x04 \x01(\x0b\x32\".bilibili.dynamic.gateway.LikeInfo\x12\x12\n\nno_comment\x18\x05 \x01(\x08\x12\x12\n\nno_forward\x18\x06 \x01(\x08\x12\x11\n\treply_url\x18\x07 \x01(\t\x12\x17\n\x0fno_comment_text\x18\x08 \x01(\t\x12\x17\n\x0fno_forward_text\x18\t \x01(\t\"F\n\tModuleTop\x12\x39\n\x07tp_list\x18\x01 \x03(\x0b\x32(.bilibili.dynamic.gateway.ThreePointItem\"l\n\tNameplate\x12\x0b\n\x03nid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bimage_small\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\t\x12\x11\n\tcondition\x18\x06 \x01(\t\"6\n\x05NewEP\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nindex_show\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\"\t\n\x07NoReply\"\x07\n\x05NoReq\">\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x10\n\x08is_atten\x18\x03 \x01(\x05\";\n\tPGCSeason\x12\x11\n\tis_finish\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"J\n\nPlayerArgs\x12\n\n\x02qn\x18\x01 \x01(\x03\x12\r\n\x05\x66nver\x18\x02 \x01(\x03\x12\r\n\x05\x66nval\x18\x03 \x01(\x03\x12\x12\n\nforce_host\x18\x04 \x01(\x03\"[\n\x0cPlayurlParam\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\r\n\x05\x66nver\x18\x02 \x01(\x05\x12\r\n\x05\x66nval\x18\x03 \x01(\x05\x12\x12\n\nforce_host\x18\x04 \x01(\x05\x12\r\n\x05\x66ourk\x18\x05 \x01(\x05\"\"\n\x0cRcmdUPsParam\x12\x12\n\ndislike_ts\x18\x01 \x01(\x03\"{\n\x08Relation\x12\x38\n\x06status\x18\x01 \x01(\x0e\x32(.bilibili.dynamic.gateway.RelationStatus\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\x12\r\n\x05title\x18\x04 \x01(\t\"<\n\x0cShareChannel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\t\"5\n\x08SortType\x12\x11\n\tsort_type\x18\x01 \x01(\x05\x12\x16\n\x0esort_type_name\x18\x02 \x01(\t\"\xc2\x01\n\x13ThreePointAttention\x12\x16\n\x0e\x61ttention_icon\x18\x01 \x01(\t\x12\x16\n\x0e\x61ttention_text\x18\x02 \x01(\t\x12\x1a\n\x12not_attention_icon\x18\x03 \x01(\t\x12\x1a\n\x12not_attention_text\x18\x04 \x01(\t\x12\x43\n\x06status\x18\x05 \x01(\x0e\x32\x33.bilibili.dynamic.gateway.ThreePointAttentionStatus\"\xe2\x01\n\x12ThreePointAutoPlay\x12\x11\n\topen_icon\x18\x01 \x01(\t\x12\x11\n\topen_text\x18\x02 \x01(\t\x12\x12\n\nclose_icon\x18\x03 \x01(\t\x12\x12\n\nclose_text\x18\x04 \x01(\t\x12\x14\n\x0copen_text_v2\x18\x05 \x01(\t\x12\x15\n\rclose_text_v2\x18\x06 \x01(\t\x12\x11\n\tonly_icon\x18\x07 \x01(\t\x12\x11\n\tonly_text\x18\x08 \x01(\t\x12\x14\n\x0copen_icon_v2\x18\t \x01(\t\x12\x15\n\rclose_icon_v2\x18\n \x01(\t\"I\n\x11ThreePointDefault\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\"0\n\x11ThreePointDislike\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"~\n\x12ThreePointFavorite\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x03\x12\x14\n\x0cis_favourite\x18\x04 \x01(\x08\x12\x13\n\x0b\x63\x61ncel_icon\x18\x05 \x01(\t\x12\x14\n\x0c\x63\x61ncel_title\x18\x06 \x01(\t\"\x91\x04\n\x0eThreePointItem\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.bilibili.dynamic.gateway.ThreePointType\x12>\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x0b\x32+.bilibili.dynamic.gateway.ThreePointDefaultH\x00\x12\x43\n\x0b\x61uto_player\x18\x03 \x01(\x0b\x32,.bilibili.dynamic.gateway.ThreePointAutoPlayH\x00\x12:\n\x05share\x18\x04 \x01(\x0b\x32).bilibili.dynamic.gateway.ThreePointShareH\x00\x12\x42\n\tattention\x18\x05 \x01(\x0b\x32-.bilibili.dynamic.gateway.ThreePointAttentionH\x00\x12\x38\n\x04wait\x18\x06 \x01(\x0b\x32(.bilibili.dynamic.gateway.ThreePointWaitH\x00\x12>\n\x07\x64islike\x18\x07 \x01(\x0b\x32+.bilibili.dynamic.gateway.ThreePointDislikeH\x00\x12@\n\x08\x66\x61vorite\x18\x08 \x01(\x0b\x32,.bilibili.dynamic.gateway.ThreePointFavoriteH\x00\x42\x06\n\x04item\"\x87\x01\n\x0fThreePointShare\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x41\n\x07\x63hannel\x18\x03 \x03(\x0b\x32\x30.bilibili.dynamic.gateway.ThreePointShareChannel\x12\x14\n\x0c\x63hannel_name\x18\x04 \x01(\t\"5\n\x16ThreePointShareChannel\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"~\n\x0eThreePointWait\x12\x15\n\raddition_icon\x18\x01 \x01(\t\x12\x15\n\raddition_text\x18\x02 \x01(\t\x12\x18\n\x10no_addition_icon\x18\x03 \x01(\t\x12\x18\n\x10no_addition_text\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\x03\"<\n\x0bTopicButton\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x10\n\x08jump_uri\x18\x03 \x01(\t\"\xd3\x01\n\tTopicList\x12\r\n\x05title\x18\x01 \x01(\t\x12@\n\x0ftopic_list_item\x18\x02 \x03(\x0b\x32\'.bilibili.dynamic.gateway.TopicListItem\x12\x39\n\nact_button\x18\x03 \x01(\x0b\x32%.bilibili.dynamic.gateway.TopicButton\x12:\n\x0bmore_button\x18\x04 \x01(\x0b\x32%.bilibili.dynamic.gateway.TopicButton\"q\n\rTopicListItem\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nicon_title\x18\x02 \x01(\t\x12\x10\n\x08topic_id\x18\x03 \x01(\x03\x12\x12\n\ntopic_name\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x0b\n\x03pos\x18\x06 \x01(\x03\"d\n\x08Unfollow\x12\r\n\x05title\x18\x01 \x01(\t\x12\x38\n\x04list\x18\x02 \x03(\x0b\x32*.bilibili.dynamic.gateway.UnfollowUserItem\x12\x0f\n\x07TrackId\x18\x03 \x01(\t\"\xda\x02\n\x10UnfollowUserItem\x12\x12\n\nhas_update\x18\x01 \x01(\x08\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\x12\x0b\n\x03pos\x18\x05 \x01(\x05\x12\x37\n\nlive_state\x18\x06 \x01(\x0e\x32#.bilibili.dynamic.gateway.LiveState\x12:\n\x08official\x18\x07 \x01(\x0b\x32(.bilibili.dynamic.gateway.OfficialVerify\x12.\n\x03vip\x18\x08 \x01(\x0b\x32!.bilibili.dynamic.gateway.VipInfo\x12\x0c\n\x04sign\x18\t \x01(\t\x12\r\n\x05label\x18\n \x01(\t\x12:\n\x06\x62utton\x18\x0b \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionalButton\"\x9e\x03\n\nUpListItem\x12\x12\n\nhas_update\x18\x01 \x01(\x08\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\x12\x0b\n\x03pos\x18\x05 \x01(\x03\x12>\n\x0euser_item_type\x18\x06 \x01(\x0e\x32&.bilibili.dynamic.gateway.UserItemType\x12\x42\n\x11\x64isplay_style_day\x18\x07 \x01(\x0b\x32\'.bilibili.dynamic.gateway.UserItemStyle\x12\x44\n\x13\x64isplay_style_night\x18\x08 \x01(\x0b\x32\'.bilibili.dynamic.gateway.UserItemStyle\x12\x10\n\x08style_id\x18\t \x01(\x03\x12\x37\n\nlive_state\x18\n \x01(\x0e\x32#.bilibili.dynamic.gateway.LiveState\x12\x11\n\tseparator\x18\x0b \x01(\x08\x12\x0b\n\x03uri\x18\x0c \x01(\t\x12\x11\n\tis_recall\x18\r \x01(\x08\"-\n\x0fUpListMoreLabel\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xce\x02\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12:\n\x08official\x18\x04 \x01(\x0b\x32(.bilibili.dynamic.gateway.OfficialVerify\x12.\n\x03vip\x18\x05 \x01(\x0b\x32!.bilibili.dynamic.gateway.VipInfo\x12\x30\n\x04live\x18\x06 \x01(\x0b\x32\".bilibili.dynamic.gateway.LiveInfo\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x36\n\x07pendant\x18\x08 \x01(\x0b\x32%.bilibili.dynamic.gateway.UserPendant\x12\x36\n\tnameplate\x18\t \x01(\x0b\x32#.bilibili.dynamic.gateway.Nameplate\"~\n\rUserItemStyle\x12\x11\n\trect_text\x18\x01 \x01(\t\x12\x17\n\x0frect_text_color\x18\x02 \x01(\t\x12\x11\n\trect_icon\x18\x03 \x01(\t\x12\x15\n\rrect_bg_color\x18\x04 \x01(\t\x12\x17\n\x0fouter_animation\x18\x05 \x01(\t\"G\n\x0bUserPendant\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\"\xe0\x01\n\nVideoBadge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\x12\x10\n\x08\x62g_alpha\x18\t \x01(\x05\x12\x16\n\x0e\x62g_alpha_night\x18\n \x01(\x05\"\xb2\x01\n\x07VipInfo\x12\x0c\n\x04Type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\x03\x12\x31\n\x05label\x18\x04 \x01(\x0b\x32\".bilibili.dynamic.gateway.VipLabel\x12\x12\n\ntheme_type\x18\x05 \x01(\x05\x12\x18\n\x10\x61vatar_subscript\x18\x06 \x01(\x05\x12\x16\n\x0enickname_color\x18\x07 \x01(\t\";\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x13\n\x0blabel_theme\x18\x03 \x01(\t\"Z\n\x06Weight\x12\r\n\x05title\x18\x01 \x01(\t\x12\x33\n\x05items\x18\x02 \x03(\x0b\x32$.bilibili.dynamic.gateway.WeightItem\x12\x0c\n\x04icon\x18\x03 \x01(\t\"/\n\x0cWeightButton\x12\x10\n\x08jump_url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"6\n\rWeightDislike\x12\x16\n\x0e\x66\x65\x65\x64_back_type\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"\xbe\x01\n\nWeightItem\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32$.bilibili.dynamic.gateway.WeightType\x12\x38\n\x06\x62utton\x18\x02 \x01(\x0b\x32&.bilibili.dynamic.gateway.WeightButtonH\x00\x12:\n\x07\x64islike\x18\x03 \x01(\x0b\x32\'.bilibili.dynamic.gateway.WeightDislikeH\x00\x42\x06\n\x04item*2\n\x10\x41\x64\x64\x42uttonBgStyle\x12\x08\n\x04\x66ill\x10\x00\x12\n\n\x06stroke\x10\x01\x12\x08\n\x04gray\x10\x02*8\n\rAddButtonType\x12\x0b\n\x07\x62t_none\x10\x00\x12\x0b\n\x07\x62t_jump\x10\x01\x12\r\n\tbt_button\x10\x02*n\n\x11\x41\x64\x64itionVoteState\x12\x1c\n\x18\x61\x64\x64ition_vote_state_none\x10\x00\x12\x1c\n\x18\x61\x64\x64ition_vote_state_open\x10\x01\x12\x1d\n\x19\x61\x64\x64ition_vote_state_close\x10\x02*\x88\x01\n\x10\x41\x64\x64itionVoteType\x12\x1b\n\x17\x61\x64\x64ition_vote_type_none\x10\x00\x12\x1b\n\x17\x61\x64\x64ition_vote_type_word\x10\x01\x12\x1a\n\x16\x61\x64\x64ition_vote_type_pic\x10\x02\x12\x1e\n\x1a\x61\x64\x64ition_vote_type_default\x10\x03*9\n\x19\x41\x64\x64itionalButtonClickType\x12\x0e\n\nclick_none\x10\x00\x12\x0c\n\x08\x63lick_up\x10\x01*:\n\x16\x41\x64\x64itionalButtonStatus\x12\x08\n\x04none\x10\x00\x12\x0b\n\x07uncheck\x10\x01\x12\t\n\x05\x63heck\x10\x02*\x85\x02\n\x0e\x41\x64\x64itionalType\x12\x13\n\x0f\x61\x64\x64itional_none\x10\x00\x12\x17\n\x13\x61\x64\x64itional_type_pgc\x10\x01\x12\x19\n\x15\x61\x64\x64itional_type_goods\x10\x02\x12\x18\n\x14\x61\x64\x64itional_type_vote\x10\x03\x12\x1a\n\x16\x61\x64\x64itional_type_common\x10\x04\x12\x1a\n\x16\x61\x64\x64itional_type_esport\x10\x05\x12\x1b\n\x17\x61\x64\x64itional_type_up_rcmd\x10\x06\x12\x17\n\x13\x61\x64\x64itional_type_ugc\x10\x07\x12\"\n\x1e\x61\x64\x64itional_type_up_reservation\x10\x08*\xf9\x02\n\x08\x44\x65scType\x12\x12\n\x0e\x64\x65sc_type_none\x10\x00\x12\x12\n\x0e\x64\x65sc_type_text\x10\x01\x12\x12\n\x0e\x64\x65sc_type_aite\x10\x02\x12\x15\n\x11\x64\x65sc_type_lottery\x10\x03\x12\x12\n\x0e\x64\x65sc_type_vote\x10\x04\x12\x13\n\x0f\x64\x65sc_type_topic\x10\x05\x12\x13\n\x0f\x64\x65sc_type_goods\x10\x06\x12\x10\n\x0c\x64\x65sc_type_bv\x10\x07\x12\x10\n\x0c\x64\x65sc_type_av\x10\x08\x12\x13\n\x0f\x64\x65sc_type_emoji\x10\t\x12\x12\n\x0e\x64\x65sc_type_user\x10\n\x12\x10\n\x0c\x64\x65sc_type_cv\x10\x0b\x12\x10\n\x0c\x64\x65sc_type_vc\x10\x0c\x12\x11\n\rdesc_type_web\x10\r\x12\x14\n\x10\x64\x65sc_type_taobao\x10\x0e\x12\x12\n\x0e\x64\x65sc_type_mail\x10\x0f\x12\x18\n\x14\x64\x65sc_type_ogv_season\x10\x10\x12\x14\n\x10\x64\x65sc_type_ogv_ep\x10\x11*\'\n\x0c\x44isableState\x12\r\n\thighlight\x10\x00\x12\x08\n\x04gary\x10\x01*\xe5\x01\n\rDynExtendType\x12\x15\n\x11\x64yn_ext_type_none\x10\x00\x12\x16\n\x12\x64yn_ext_type_topic\x10\x01\x12\x14\n\x10\x64yn_ext_type_lbs\x10\x02\x12\x14\n\x10\x64yn_ext_type_hot\x10\x03\x12\x15\n\x11\x64yn_ext_type_game\x10\x04\x12\x17\n\x13\x64yn_ext_type_common\x10\x05\x12\x18\n\x14\x64yn_ext_type_biliCut\x10\x06\x12\x14\n\x10\x64yn_ext_type_ogv\x10\x07\x12\x19\n\x15\x64yn_ext_type_auto_ogv\x10\x08*\xc9\x03\n\rDynModuleType\x12\x0f\n\x0bmodule_none\x10\x00\x12\x11\n\rmodule_author\x10\x01\x12\x12\n\x0emodule_dispute\x10\x02\x12\x0f\n\x0bmodule_desc\x10\x03\x12\x12\n\x0emodule_dynamic\x10\x04\x12\x12\n\x0emodule_forward\x10\x05\x12\x13\n\x0fmodule_likeUser\x10\x06\x12\x11\n\rmodule_extend\x10\x07\x12\x15\n\x11module_additional\x10\x08\x12\x0f\n\x0bmodule_stat\x10\t\x12\x0f\n\x0bmodule_fold\x10\n\x12\x12\n\x0emodule_comment\x10\x0b\x12\x16\n\x12module_interaction\x10\x0c\x12\x19\n\x15module_author_forward\x10\r\x12\r\n\tmodule_ad\x10\x0e\x12\x11\n\rmodule_banner\x10\x0f\x12\x14\n\x10module_item_null\x10\x10\x12\x15\n\x11module_share_info\x10\x11\x12\x14\n\x10module_recommend\x10\x12\x12\x17\n\x13module_stat_forward\x10\x13\x12\x0e\n\nmodule_top\x10\x14\x12\x11\n\rmodule_bottom\x10\x15*U\n\nDynUriType\x12\x15\n\x11\x64yn_uri_type_none\x10\x00\x12\x17\n\x13\x64yn_uri_type_direct\x10\x01\x12\x17\n\x13\x64yn_uri_type_suffix\x10\x02*\xb8\x02\n\x0b\x44ynamicType\x12\x0c\n\x08\x64yn_none\x10\x00\x12\x0b\n\x07\x66orward\x10\x01\x12\x06\n\x02\x61v\x10\x02\x12\x07\n\x03pgc\x10\x03\x12\x0b\n\x07\x63ourses\x10\x04\x12\x08\n\x04\x66old\x10\x05\x12\x08\n\x04word\x10\x06\x12\x08\n\x04\x64raw\x10\x07\x12\x0b\n\x07\x61rticle\x10\x08\x12\t\n\x05music\x10\t\x12\x11\n\rcommon_square\x10\n\x12\x13\n\x0f\x63ommon_vertical\x10\x0b\x12\x08\n\x04live\x10\x0c\x12\r\n\tmedialist\x10\r\x12\x12\n\x0e\x63ourses_season\x10\x0e\x12\x06\n\x02\x61\x64\x10\x0f\x12\n\n\x06\x61pplet\x10\x10\x12\x10\n\x0csubscription\x10\x11\x12\r\n\tlive_rcmd\x10\x12\x12\n\n\x06\x62\x61nner\x10\x13\x12\x0e\n\nugc_season\x10\x14\x12\x14\n\x10subscription_new\x10\x15*B\n\tEmojiType\x12\x0e\n\nemoji_none\x10\x00\x12\r\n\temoji_old\x10\x01\x12\r\n\temoji_new\x10\x02\x12\x07\n\x03vip\x10\x03*\x17\n\x0b\x45spaceStyle\x12\x08\n\x04moba\x10\x00*m\n\x08\x46oldType\x12\x10\n\x0c\x46oldTypeZore\x10\x00\x12\x13\n\x0f\x46oldTypePublish\x10\x01\x12\x14\n\x10\x46oldTypeFrequent\x10\x02\x12\x11\n\rFoldTypeUnite\x10\x03\x12\x11\n\rFoldTypeLimit\x10\x04*.\n\nFollowType\x12\x11\n\rft_not_follow\x10\x00\x12\r\n\tft_follow\x10\x01*9\n\x12HighlightTextStyle\x12\x0e\n\nstyle_none\x10\x00\x12\x13\n\x0fstyle_highlight\x10\x01*:\n\nImageStyle\x12\x16\n\x12\x61\x64\x64_style_vertical\x10\x00\x12\x14\n\x10\x61\x64\x64_style_square\x10\x01*<\n\tLiveState\x12\r\n\tlive_none\x10\x00\x12\r\n\tlive_live\x10\x01\x12\x11\n\rlive_rotation\x10\x02*<\n\rLocalIconType\x12\x16\n\x12local_icon_comment\x10\x00\x12\x13\n\x0flocal_icon_like\x10\x01*b\n\x10MdlDynCommonType\x12\x17\n\x13mdl_dyn_common_none\x10\x00\x12\x19\n\x15mdl_dyn_common_square\x10\x01\x12\x1a\n\x16mdl_dyn_common_vertica\x10\x02*\xa0\x01\n\x11MdlDynDrawTagType\x12\x15\n\x11mdl_draw_tag_none\x10\x00\x12\x17\n\x13mdl_draw_tag_common\x10\x01\x12\x16\n\x12mdl_draw_tag_goods\x10\x02\x12\x15\n\x11mdl_draw_tag_user\x10\x03\x12\x16\n\x12mdl_draw_tag_topic\x10\x04\x12\x14\n\x10mdl_draw_tag_lbs\x10\x05*\x97\x01\n\x1aMdlDynSubscriptionNewStyle\x12\'\n#mdl_dyn_subscription_new_style_nont\x10\x00\x12\'\n#mdl_dyn_subscription_new_style_live\x10\x01\x12\'\n#mdl_dyn_subscription_new_style_draw\x10\x02*g\n\tMediaType\x12\x11\n\rMediaTypeNone\x10\x00\x12\x10\n\x0cMediaTypeUGC\x10\x01\x12\x10\n\x0cMediaTypePGC\x10\x02\x12\x11\n\rMediaTypeLive\x10\x03\x12\x10\n\x0cMediaTypeVCS\x10\x04*\xad\x01\n\x15ModuleAuthorBadgeType\x12!\n\x1dmodule_author_badge_type_none\x10\x00\x12\'\n#module_author_badge_type_threePoint\x10\x01\x12#\n\x1fmodule_author_badge_type_button\x10\x02\x12#\n\x1fmodule_author_badge_type_weight\x10\x03*L\n\x10ModuleBannerType\x12\x1b\n\x17module_banner_type_none\x10\x00\x12\x1b\n\x17module_banner_type_user\x10\x01*\xf1\x02\n\x11ModuleDynamicType\x12\x13\n\x0fmdl_dyn_archive\x10\x00\x12\x0f\n\x0bmdl_dyn_pgc\x10\x01\x12\x17\n\x13mdl_dyn_cour_season\x10\x02\x12\x16\n\x12mdl_dyn_cour_batch\x10\x03\x12\x13\n\x0fmdl_dyn_forward\x10\x04\x12\x10\n\x0cmdl_dyn_draw\x10\x05\x12\x13\n\x0fmdl_dyn_article\x10\x06\x12\x11\n\rmdl_dyn_music\x10\x07\x12\x12\n\x0emdl_dyn_common\x10\x08\x12\x10\n\x0cmdl_dyn_live\x10\t\x12\x15\n\x11mdl_dyn_medialist\x10\n\x12\x12\n\x0emdl_dyn_applet\x10\x0b\x12\x18\n\x14mdl_dyn_subscription\x10\x0c\x12\x15\n\x11mdl_dyn_live_rcmd\x10\r\x12\x16\n\x12mdl_dyn_ugc_season\x10\x0e\x12\x1c\n\x18mdl_dyn_subscription_new\x10\x0f*/\n\x07Refresh\x12\x0f\n\x0brefresh_new\x10\x00\x12\x13\n\x0frefresh_history\x10\x01*\xc3\x01\n\x0eRelationStatus\x12\x18\n\x14relation_status_none\x10\x00\x12\x1c\n\x18relation_status_nofollow\x10\x01\x12\x1a\n\x16relation_status_follow\x10\x02\x12\x1c\n\x18relation_status_followed\x10\x03\x12\"\n\x1erelation_status_mutual_concern\x10\x04\x12\x1b\n\x17relation_status_special\x10\x05*3\n\x0bReserveType\x12\x10\n\x0creserve_none\x10\x00\x12\x12\n\x0ereserve_recall\x10\x01*C\n\x19ThreePointAttentionStatus\x12\x14\n\x10tp_not_attention\x10\x00\x12\x10\n\x0ctp_attention\x10\x01*\x93\x01\n\x0eThreePointType\x12\x0b\n\x07tp_none\x10\x00\x12\x0e\n\nbackground\x10\x01\x12\r\n\tauto_play\x10\x02\x12\t\n\x05share\x10\x03\x12\x08\n\x04wait\x10\x04\x12\r\n\tattention\x10\x05\x12\n\n\x06report\x10\x06\x12\n\n\x06\x64\x65lete\x10\x07\x12\x0b\n\x07\x64islike\x10\x08\x12\x0c\n\x08\x66\x61vorite\x10\t*\"\n\tThumbType\x12\n\n\x06\x63\x61ncel\x10\x00\x12\t\n\x05thumb\x10\x01*\x96\x01\n\x0cUserItemType\x12\x17\n\x13user_item_type_none\x10\x00\x12\x17\n\x13user_item_type_live\x10\x01\x12\x1e\n\x1auser_item_type_live_custom\x10\x02\x12\x19\n\x15user_item_type_normal\x10\x03\x12\x19\n\x15user_item_type_extend\x10\x04*\xa5\x01\n\x0cVideoSubType\x12\x14\n\x10VideoSubTypeNone\x10\x00\x12\x17\n\x13VideoSubTypeBangumi\x10\x01\x12\x15\n\x11VideoSubTypeMovie\x10\x02\x12\x1b\n\x17VideoSubTypeDocumentary\x10\x03\x12\x18\n\x14VideoSubTypeDomestic\x10\x04\x12\x18\n\x14VideoSubTypeTeleplay\x10\x05*T\n\tVideoType\x12\x16\n\x12video_type_general\x10\x00\x12\x16\n\x12video_type_dynamic\x10\x01\x12\x17\n\x13video_type_playback\x10\x02*\'\n\nVoteStatus\x12\n\n\x06normal\x10\x00\x12\r\n\tanonymous\x10\x01*B\n\nWeightType\x12\x0f\n\x0bweight_none\x10\x00\x12\x12\n\x0eweight_dislike\x10\x01\x12\x0f\n\x0bweight_jump\x10\x02\x62\x06proto3')

_ADDBUTTONBGSTYLE = DESCRIPTOR.enum_types_by_name['AddButtonBgStyle']
AddButtonBgStyle = enum_type_wrapper.EnumTypeWrapper(_ADDBUTTONBGSTYLE)
_ADDBUTTONTYPE = DESCRIPTOR.enum_types_by_name['AddButtonType']
AddButtonType = enum_type_wrapper.EnumTypeWrapper(_ADDBUTTONTYPE)
_ADDITIONVOTESTATE = DESCRIPTOR.enum_types_by_name['AdditionVoteState']
AdditionVoteState = enum_type_wrapper.EnumTypeWrapper(_ADDITIONVOTESTATE)
_ADDITIONVOTETYPE = DESCRIPTOR.enum_types_by_name['AdditionVoteType']
AdditionVoteType = enum_type_wrapper.EnumTypeWrapper(_ADDITIONVOTETYPE)
_ADDITIONALBUTTONCLICKTYPE = DESCRIPTOR.enum_types_by_name['AdditionalButtonClickType']
AdditionalButtonClickType = enum_type_wrapper.EnumTypeWrapper(_ADDITIONALBUTTONCLICKTYPE)
_ADDITIONALBUTTONSTATUS = DESCRIPTOR.enum_types_by_name['AdditionalButtonStatus']
AdditionalButtonStatus = enum_type_wrapper.EnumTypeWrapper(_ADDITIONALBUTTONSTATUS)
_ADDITIONALTYPE = DESCRIPTOR.enum_types_by_name['AdditionalType']
AdditionalType = enum_type_wrapper.EnumTypeWrapper(_ADDITIONALTYPE)
_DESCTYPE = DESCRIPTOR.enum_types_by_name['DescType']
DescType = enum_type_wrapper.EnumTypeWrapper(_DESCTYPE)
_DISABLESTATE = DESCRIPTOR.enum_types_by_name['DisableState']
DisableState = enum_type_wrapper.EnumTypeWrapper(_DISABLESTATE)
_DYNEXTENDTYPE = DESCRIPTOR.enum_types_by_name['DynExtendType']
DynExtendType = enum_type_wrapper.EnumTypeWrapper(_DYNEXTENDTYPE)
_DYNMODULETYPE = DESCRIPTOR.enum_types_by_name['DynModuleType']
DynModuleType = enum_type_wrapper.EnumTypeWrapper(_DYNMODULETYPE)
_DYNURITYPE = DESCRIPTOR.enum_types_by_name['DynUriType']
DynUriType = enum_type_wrapper.EnumTypeWrapper(_DYNURITYPE)
_DYNAMICTYPE = DESCRIPTOR.enum_types_by_name['DynamicType']
DynamicType = enum_type_wrapper.EnumTypeWrapper(_DYNAMICTYPE)
_EMOJITYPE = DESCRIPTOR.enum_types_by_name['EmojiType']
EmojiType = enum_type_wrapper.EnumTypeWrapper(_EMOJITYPE)
_ESPACESTYLE = DESCRIPTOR.enum_types_by_name['EspaceStyle']
EspaceStyle = enum_type_wrapper.EnumTypeWrapper(_ESPACESTYLE)
_FOLDTYPE = DESCRIPTOR.enum_types_by_name['FoldType']
FoldType = enum_type_wrapper.EnumTypeWrapper(_FOLDTYPE)
_FOLLOWTYPE = DESCRIPTOR.enum_types_by_name['FollowType']
FollowType = enum_type_wrapper.EnumTypeWrapper(_FOLLOWTYPE)
_HIGHLIGHTTEXTSTYLE = DESCRIPTOR.enum_types_by_name['HighlightTextStyle']
HighlightTextStyle = enum_type_wrapper.EnumTypeWrapper(_HIGHLIGHTTEXTSTYLE)
_IMAGESTYLE = DESCRIPTOR.enum_types_by_name['ImageStyle']
ImageStyle = enum_type_wrapper.EnumTypeWrapper(_IMAGESTYLE)
_LIVESTATE = DESCRIPTOR.enum_types_by_name['LiveState']
LiveState = enum_type_wrapper.EnumTypeWrapper(_LIVESTATE)
_LOCALICONTYPE = DESCRIPTOR.enum_types_by_name['LocalIconType']
LocalIconType = enum_type_wrapper.EnumTypeWrapper(_LOCALICONTYPE)
_MDLDYNCOMMONTYPE = DESCRIPTOR.enum_types_by_name['MdlDynCommonType']
MdlDynCommonType = enum_type_wrapper.EnumTypeWrapper(_MDLDYNCOMMONTYPE)
_MDLDYNDRAWTAGTYPE = DESCRIPTOR.enum_types_by_name['MdlDynDrawTagType']
MdlDynDrawTagType = enum_type_wrapper.EnumTypeWrapper(_MDLDYNDRAWTAGTYPE)
_MDLDYNSUBSCRIPTIONNEWSTYLE = DESCRIPTOR.enum_types_by_name['MdlDynSubscriptionNewStyle']
MdlDynSubscriptionNewStyle = enum_type_wrapper.EnumTypeWrapper(_MDLDYNSUBSCRIPTIONNEWSTYLE)
_MEDIATYPE = DESCRIPTOR.enum_types_by_name['MediaType']
MediaType = enum_type_wrapper.EnumTypeWrapper(_MEDIATYPE)
_MODULEAUTHORBADGETYPE = DESCRIPTOR.enum_types_by_name['ModuleAuthorBadgeType']
ModuleAuthorBadgeType = enum_type_wrapper.EnumTypeWrapper(_MODULEAUTHORBADGETYPE)
_MODULEBANNERTYPE = DESCRIPTOR.enum_types_by_name['ModuleBannerType']
ModuleBannerType = enum_type_wrapper.EnumTypeWrapper(_MODULEBANNERTYPE)
_MODULEDYNAMICTYPE = DESCRIPTOR.enum_types_by_name['ModuleDynamicType']
ModuleDynamicType = enum_type_wrapper.EnumTypeWrapper(_MODULEDYNAMICTYPE)
_REFRESH = DESCRIPTOR.enum_types_by_name['Refresh']
Refresh = enum_type_wrapper.EnumTypeWrapper(_REFRESH)
_RELATIONSTATUS = DESCRIPTOR.enum_types_by_name['RelationStatus']
RelationStatus = enum_type_wrapper.EnumTypeWrapper(_RELATIONSTATUS)
_RESERVETYPE = DESCRIPTOR.enum_types_by_name['ReserveType']
ReserveType = enum_type_wrapper.EnumTypeWrapper(_RESERVETYPE)
_THREEPOINTATTENTIONSTATUS = DESCRIPTOR.enum_types_by_name['ThreePointAttentionStatus']
ThreePointAttentionStatus = enum_type_wrapper.EnumTypeWrapper(_THREEPOINTATTENTIONSTATUS)
_THREEPOINTTYPE = DESCRIPTOR.enum_types_by_name['ThreePointType']
ThreePointType = enum_type_wrapper.EnumTypeWrapper(_THREEPOINTTYPE)
_THUMBTYPE = DESCRIPTOR.enum_types_by_name['ThumbType']
ThumbType = enum_type_wrapper.EnumTypeWrapper(_THUMBTYPE)
_USERITEMTYPE = DESCRIPTOR.enum_types_by_name['UserItemType']
UserItemType = enum_type_wrapper.EnumTypeWrapper(_USERITEMTYPE)
_VIDEOSUBTYPE = DESCRIPTOR.enum_types_by_name['VideoSubType']
VideoSubType = enum_type_wrapper.EnumTypeWrapper(_VIDEOSUBTYPE)
_VIDEOTYPE = DESCRIPTOR.enum_types_by_name['VideoType']
VideoType = enum_type_wrapper.EnumTypeWrapper(_VIDEOTYPE)
_VOTESTATUS = DESCRIPTOR.enum_types_by_name['VoteStatus']
VoteStatus = enum_type_wrapper.EnumTypeWrapper(_VOTESTATUS)
_WEIGHTTYPE = DESCRIPTOR.enum_types_by_name['WeightType']
WeightType = enum_type_wrapper.EnumTypeWrapper(_WEIGHTTYPE)
fill = 0
stroke = 1
gray = 2
bt_none = 0
bt_jump = 1
bt_button = 2
addition_vote_state_none = 0
addition_vote_state_open = 1
addition_vote_state_close = 2
addition_vote_type_none = 0
addition_vote_type_word = 1
addition_vote_type_pic = 2
addition_vote_type_default = 3
click_none = 0
click_up = 1
none = 0
uncheck = 1
check = 2
additional_none = 0
additional_type_pgc = 1
additional_type_goods = 2
additional_type_vote = 3
additional_type_common = 4
additional_type_esport = 5
additional_type_up_rcmd = 6
additional_type_ugc = 7
additional_type_up_reservation = 8
desc_type_none = 0
desc_type_text = 1
desc_type_aite = 2
desc_type_lottery = 3
desc_type_vote = 4
desc_type_topic = 5
desc_type_goods = 6
desc_type_bv = 7
desc_type_av = 8
desc_type_emoji = 9
desc_type_user = 10
desc_type_cv = 11
desc_type_vc = 12
desc_type_web = 13
desc_type_taobao = 14
desc_type_mail = 15
desc_type_ogv_season = 16
desc_type_ogv_ep = 17
highlight = 0
gary = 1
dyn_ext_type_none = 0
dyn_ext_type_topic = 1
dyn_ext_type_lbs = 2
dyn_ext_type_hot = 3
dyn_ext_type_game = 4
dyn_ext_type_common = 5
dyn_ext_type_biliCut = 6
dyn_ext_type_ogv = 7
dyn_ext_type_auto_ogv = 8
module_none = 0
module_author = 1
module_dispute = 2
module_desc = 3
module_dynamic = 4
module_forward = 5
module_likeUser = 6
module_extend = 7
module_additional = 8
module_stat = 9
module_fold = 10
module_comment = 11
module_interaction = 12
module_author_forward = 13
module_ad = 14
module_banner = 15
module_item_null = 16
module_share_info = 17
module_recommend = 18
module_stat_forward = 19
module_top = 20
module_bottom = 21
dyn_uri_type_none = 0
dyn_uri_type_direct = 1
dyn_uri_type_suffix = 2
dyn_none = 0
forward = 1
av = 2
pgc = 3
courses = 4
fold = 5
word = 6
draw = 7
article = 8
music = 9
common_square = 10
common_vertical = 11
live = 12
medialist = 13
courses_season = 14
ad = 15
applet = 16
subscription = 17
live_rcmd = 18
banner = 19
ugc_season = 20
subscription_new = 21
emoji_none = 0
emoji_old = 1
emoji_new = 2
vip = 3
moba = 0
FoldTypeZore = 0
FoldTypePublish = 1
FoldTypeFrequent = 2
FoldTypeUnite = 3
FoldTypeLimit = 4
ft_not_follow = 0
ft_follow = 1
style_none = 0
style_highlight = 1
add_style_vertical = 0
add_style_square = 1
live_none = 0
live_live = 1
live_rotation = 2
local_icon_comment = 0
local_icon_like = 1
mdl_dyn_common_none = 0
mdl_dyn_common_square = 1
mdl_dyn_common_vertica = 2
mdl_draw_tag_none = 0
mdl_draw_tag_common = 1
mdl_draw_tag_goods = 2
mdl_draw_tag_user = 3
mdl_draw_tag_topic = 4
mdl_draw_tag_lbs = 5
mdl_dyn_subscription_new_style_nont = 0
mdl_dyn_subscription_new_style_live = 1
mdl_dyn_subscription_new_style_draw = 2
MediaTypeNone = 0
MediaTypeUGC = 1
MediaTypePGC = 2
MediaTypeLive = 3
MediaTypeVCS = 4
module_author_badge_type_none = 0
module_author_badge_type_threePoint = 1
module_author_badge_type_button = 2
module_author_badge_type_weight = 3
module_banner_type_none = 0
module_banner_type_user = 1
mdl_dyn_archive = 0
mdl_dyn_pgc = 1
mdl_dyn_cour_season = 2
mdl_dyn_cour_batch = 3
mdl_dyn_forward = 4
mdl_dyn_draw = 5
mdl_dyn_article = 6
mdl_dyn_music = 7
mdl_dyn_common = 8
mdl_dyn_live = 9
mdl_dyn_medialist = 10
mdl_dyn_applet = 11
mdl_dyn_subscription = 12
mdl_dyn_live_rcmd = 13
mdl_dyn_ugc_season = 14
mdl_dyn_subscription_new = 15
refresh_new = 0
refresh_history = 1
relation_status_none = 0
relation_status_nofollow = 1
relation_status_follow = 2
relation_status_followed = 3
relation_status_mutual_concern = 4
relation_status_special = 5
reserve_none = 0
reserve_recall = 1
tp_not_attention = 0
tp_attention = 1
tp_none = 0
background = 1
auto_play = 2
share = 3
wait = 4
attention = 5
report = 6
delete = 7
dislike = 8
favorite = 9
cancel = 0
thumb = 1
user_item_type_none = 0
user_item_type_live = 1
user_item_type_live_custom = 2
user_item_type_normal = 3
user_item_type_extend = 4
VideoSubTypeNone = 0
VideoSubTypeBangumi = 1
VideoSubTypeMovie = 2
VideoSubTypeDocumentary = 3
VideoSubTypeDomestic = 4
VideoSubTypeTeleplay = 5
video_type_general = 0
video_type_dynamic = 1
video_type_playback = 2
normal = 0
anonymous = 1
weight_none = 0
weight_dislike = 1
weight_jump = 2


_ADPARAM = DESCRIPTOR.message_types_by_name['AdParam']
_ADDITIONCOMMON = DESCRIPTOR.message_types_by_name['AdditionCommon']
_ADDITIONESPORT = DESCRIPTOR.message_types_by_name['AdditionEsport']
_ADDITIONESPORTMOBA = DESCRIPTOR.message_types_by_name['AdditionEsportMoba']
_ADDITIONESPORTMOBASTATUS = DESCRIPTOR.message_types_by_name['AdditionEsportMobaStatus']
_ADDITIONESPORTMOBASTATUSDESC = DESCRIPTOR.message_types_by_name['AdditionEsportMobaStatusDesc']
_ADDITIONGOODS = DESCRIPTOR.message_types_by_name['AdditionGoods']
_ADDITIONUP = DESCRIPTOR.message_types_by_name['AdditionUP']
_ADDITIONUGC = DESCRIPTOR.message_types_by_name['AdditionUgc']
_ADDITIONVOTE = DESCRIPTOR.message_types_by_name['AdditionVote']
_ADDITIONVOTE2 = DESCRIPTOR.message_types_by_name['AdditionVote2']
_ADDITIONVOTEDEFAULE = DESCRIPTOR.message_types_by_name['AdditionVoteDefaule']
_ADDITIONVOTEPIC = DESCRIPTOR.message_types_by_name['AdditionVotePic']
_ADDITIONVOTEPICITEM = DESCRIPTOR.message_types_by_name['AdditionVotePicItem']
_ADDITIONVOTEWORD = DESCRIPTOR.message_types_by_name['AdditionVoteWord']
_ADDITIONVOTEWORDITEM = DESCRIPTOR.message_types_by_name['AdditionVoteWordItem']
_ADDITIONALACTSKIN = DESCRIPTOR.message_types_by_name['AdditionalActSkin']
_ADDITIONALBUTTON = DESCRIPTOR.message_types_by_name['AdditionalButton']
_ADDITIONALBUTTONINTERACTIVE = DESCRIPTOR.message_types_by_name['AdditionalButtonInteractive']
_ADDITIONALBUTTONSTYLE = DESCRIPTOR.message_types_by_name['AdditionalButtonStyle']
_ADDITIONALPGC = DESCRIPTOR.message_types_by_name['AdditionalPGC']
_CARDVIDEODYNLIST = DESCRIPTOR.message_types_by_name['CardVideoDynList']
_CARDVIDEOFOLLOWLIST = DESCRIPTOR.message_types_by_name['CardVideoFollowList']
_CARDVIDEOUPLIST = DESCRIPTOR.message_types_by_name['CardVideoUpList']
_CMTSHOWITEM = DESCRIPTOR.message_types_by_name['CmtShowItem']
_DECOCARDFAN = DESCRIPTOR.message_types_by_name['DecoCardFan']
_DECORATECARD = DESCRIPTOR.message_types_by_name['DecorateCard']
_DESCRIPTION = DESCRIPTOR.message_types_by_name['Description']
_DIMENSION = DESCRIPTOR.message_types_by_name['Dimension']
_DYNADDITIONCOMMONFOLLOWREPLY = DESCRIPTOR.message_types_by_name['DynAdditionCommonFollowReply']
_DYNADDITIONCOMMONFOLLOWREQ = DESCRIPTOR.message_types_by_name['DynAdditionCommonFollowReq']
_DYNALLPERSONALREPLY = DESCRIPTOR.message_types_by_name['DynAllPersonalReply']
_DYNALLPERSONALREQ = DESCRIPTOR.message_types_by_name['DynAllPersonalReq']
_DYNALLREPLY = DESCRIPTOR.message_types_by_name['DynAllReply']
_DYNALLREQ = DESCRIPTOR.message_types_by_name['DynAllReq']
_DYNALLUPDOFFSETREQ = DESCRIPTOR.message_types_by_name['DynAllUpdOffsetReq']
_DYNDETAILREPLY = DESCRIPTOR.message_types_by_name['DynDetailReply']
_DYNDETAILSREQ = DESCRIPTOR.message_types_by_name['DynDetailsReq']
_DYNFAKECARDREPLY = DESCRIPTOR.message_types_by_name['DynFakeCardReply']
_DYNFAKECARDREQ = DESCRIPTOR.message_types_by_name['DynFakeCardReq']
_DYNMIXUPLISTVIEWMOREREPLY = DESCRIPTOR.message_types_by_name['DynMixUpListViewMoreReply']
_DYNMIXUPLISTVIEWMOREREQ = DESCRIPTOR.message_types_by_name['DynMixUpListViewMoreReq']
_DYNRCMDUPEXCHANGEREPLY = DESCRIPTOR.message_types_by_name['DynRcmdUpExchangeReply']
_DYNRCMDUPEXCHANGEREQ = DESCRIPTOR.message_types_by_name['DynRcmdUpExchangeReq']
_DYNTHUMBREQ = DESCRIPTOR.message_types_by_name['DynThumbReq']
_DYNVIDEOPERSONALREPLY = DESCRIPTOR.message_types_by_name['DynVideoPersonalReply']
_DYNVIDEOPERSONALREQ = DESCRIPTOR.message_types_by_name['DynVideoPersonalReq']
_DYNVIDEOREPLY = DESCRIPTOR.message_types_by_name['DynVideoReply']
_DYNVIDEOREQ = DESCRIPTOR.message_types_by_name['DynVideoReq']
_DYNVIDEOUPDOFFSETREQ = DESCRIPTOR.message_types_by_name['DynVideoUpdOffsetReq']
_DYNVOTEREPLY = DESCRIPTOR.message_types_by_name['DynVoteReply']
_DYNVOTEREQ = DESCRIPTOR.message_types_by_name['DynVoteReq']
_DYNAMICITEM = DESCRIPTOR.message_types_by_name['DynamicItem']
_DYNAMICLIST = DESCRIPTOR.message_types_by_name['DynamicList']
_EXTINFOCOMMON = DESCRIPTOR.message_types_by_name['ExtInfoCommon']
_EXTINFOGAME = DESCRIPTOR.message_types_by_name['ExtInfoGame']
_EXTINFOHOT = DESCRIPTOR.message_types_by_name['ExtInfoHot']
_EXTINFOLBS = DESCRIPTOR.message_types_by_name['ExtInfoLBS']
_EXTINFOOGV = DESCRIPTOR.message_types_by_name['ExtInfoOGV']
_EXTINFOTOPIC = DESCRIPTOR.message_types_by_name['ExtInfoTopic']
_EXTEND = DESCRIPTOR.message_types_by_name['Extend']
_EXTENDREPLY = DESCRIPTOR.message_types_by_name['ExtendReply']
_EXTENDREPLYPARAM = DESCRIPTOR.message_types_by_name['ExtendReplyParam']
_FOLLOWLISTITEM = DESCRIPTOR.message_types_by_name['FollowListItem']
_GOODSITEM = DESCRIPTOR.message_types_by_name['GoodsItem']
_HIGHLIGHTTEXT = DESCRIPTOR.message_types_by_name['HighlightText']
_INFOOGV = DESCRIPTOR.message_types_by_name['InfoOGV']
_INTERACTIONITEM = DESCRIPTOR.message_types_by_name['InteractionItem']
_LIKEANIMATION = DESCRIPTOR.message_types_by_name['LikeAnimation']
_LIKEINFO = DESCRIPTOR.message_types_by_name['LikeInfo']
_LIKEUSER = DESCRIPTOR.message_types_by_name['LikeUser']
_LIVEINFO = DESCRIPTOR.message_types_by_name['LiveInfo']
_MATCHTEAM = DESCRIPTOR.message_types_by_name['MatchTeam']
_MDLDYNAPPLET = DESCRIPTOR.message_types_by_name['MdlDynApplet']
_MDLDYNARCHIVE = DESCRIPTOR.message_types_by_name['MdlDynArchive']
_MDLDYNARTICLE = DESCRIPTOR.message_types_by_name['MdlDynArticle']
_MDLDYNCOMMON = DESCRIPTOR.message_types_by_name['MdlDynCommon']
_MDLDYNCOURBATCH = DESCRIPTOR.message_types_by_name['MdlDynCourBatch']
_MDLDYNCOURSEASON = DESCRIPTOR.message_types_by_name['MdlDynCourSeason']
_MDLDYNDRAW = DESCRIPTOR.message_types_by_name['MdlDynDraw']
_MDLDYNDRAWITEM = DESCRIPTOR.message_types_by_name['MdlDynDrawItem']
_MDLDYNDRAWTAG = DESCRIPTOR.message_types_by_name['MdlDynDrawTag']
_MDLDYNDRAWTAGITEM = DESCRIPTOR.message_types_by_name['MdlDynDrawTagItem']
_MDLDYNFORWARD = DESCRIPTOR.message_types_by_name['MdlDynForward']
_MDLDYNLIVE = DESCRIPTOR.message_types_by_name['MdlDynLive']
_MDLDYNLIVERCMD = DESCRIPTOR.message_types_by_name['MdlDynLiveRcmd']
_MDLDYNMEDIALIST = DESCRIPTOR.message_types_by_name['MdlDynMedialist']
_MDLDYNMUSIC = DESCRIPTOR.message_types_by_name['MdlDynMusic']
_MDLDYNPGC = DESCRIPTOR.message_types_by_name['MdlDynPGC']
_MDLDYNSUBSCRIPTION = DESCRIPTOR.message_types_by_name['MdlDynSubscription']
_MDLDYNSUBSCRIPTIONNEW = DESCRIPTOR.message_types_by_name['MdlDynSubscriptionNew']
_MDLDYNUGCSEASON = DESCRIPTOR.message_types_by_name['MdlDynUGCSeason']
_MIXUPLISTITEM = DESCRIPTOR.message_types_by_name['MixUpListItem']
_MIXUPLISTLIVEITEM = DESCRIPTOR.message_types_by_name['MixUpListLiveItem']
_MODULE = DESCRIPTOR.message_types_by_name['Module']
_MODULEAD = DESCRIPTOR.message_types_by_name['ModuleAd']
_MODULEADDITIONAL = DESCRIPTOR.message_types_by_name['ModuleAdditional']
_MODULEAUTHOR = DESCRIPTOR.message_types_by_name['ModuleAuthor']
_MODULEAUTHORBADGEBUTTON = DESCRIPTOR.message_types_by_name['ModuleAuthorBadgeButton']
_MODULEAUTHORFORWARD = DESCRIPTOR.message_types_by_name['ModuleAuthorForward']
_MODULEAUTHORFORWARDTITLE = DESCRIPTOR.message_types_by_name['ModuleAuthorForwardTitle']
_MODULEBANNER = DESCRIPTOR.message_types_by_name['ModuleBanner']
_MODULEBANNERUSER = DESCRIPTOR.message_types_by_name['ModuleBannerUser']
_MODULEBANNERUSERITEM = DESCRIPTOR.message_types_by_name['ModuleBannerUserItem']
_MODULEBUTTOM = DESCRIPTOR.message_types_by_name['ModuleButtom']
_MODULECOMMENT = DESCRIPTOR.message_types_by_name['ModuleComment']
_MODULEDESC = DESCRIPTOR.message_types_by_name['ModuleDesc']
_MODULEDESCGOODS = DESCRIPTOR.message_types_by_name['ModuleDescGoods']
_MODULEDISPUTE = DESCRIPTOR.message_types_by_name['ModuleDispute']
_MODULEDYNAMIC = DESCRIPTOR.message_types_by_name['ModuleDynamic']
_MODULEEXTEND = DESCRIPTOR.message_types_by_name['ModuleExtend']
_MODULEEXTENDITEM = DESCRIPTOR.message_types_by_name['ModuleExtendItem']
_MODULEFOLD = DESCRIPTOR.message_types_by_name['ModuleFold']
_MODULEINTERACTION = DESCRIPTOR.message_types_by_name['ModuleInteraction']
_MODULEITEMNULL = DESCRIPTOR.message_types_by_name['ModuleItemNull']
_MODULELIKEUSER = DESCRIPTOR.message_types_by_name['ModuleLikeUser']
_MODULERECOMMEND = DESCRIPTOR.message_types_by_name['ModuleRecommend']
_MODULESHAREINFO = DESCRIPTOR.message_types_by_name['ModuleShareInfo']
_MODULESTAT = DESCRIPTOR.message_types_by_name['ModuleStat']
_MODULETOP = DESCRIPTOR.message_types_by_name['ModuleTop']
_NAMEPLATE = DESCRIPTOR.message_types_by_name['Nameplate']
_NEWEP = DESCRIPTOR.message_types_by_name['NewEP']
_NOREPLY = DESCRIPTOR.message_types_by_name['NoReply']
_NOREQ = DESCRIPTOR.message_types_by_name['NoReq']
_OFFICIALVERIFY = DESCRIPTOR.message_types_by_name['OfficialVerify']
_PGCSEASON = DESCRIPTOR.message_types_by_name['PGCSeason']
_PLAYERARGS = DESCRIPTOR.message_types_by_name['PlayerArgs']
_PLAYURLPARAM = DESCRIPTOR.message_types_by_name['PlayurlParam']
_RCMDUPSPARAM = DESCRIPTOR.message_types_by_name['RcmdUPsParam']
_RELATION = DESCRIPTOR.message_types_by_name['Relation']
_SHARECHANNEL = DESCRIPTOR.message_types_by_name['ShareChannel']
_SORTTYPE = DESCRIPTOR.message_types_by_name['SortType']
_THREEPOINTATTENTION = DESCRIPTOR.message_types_by_name['ThreePointAttention']
_THREEPOINTAUTOPLAY = DESCRIPTOR.message_types_by_name['ThreePointAutoPlay']
_THREEPOINTDEFAULT = DESCRIPTOR.message_types_by_name['ThreePointDefault']
_THREEPOINTDISLIKE = DESCRIPTOR.message_types_by_name['ThreePointDislike']
_THREEPOINTFAVORITE = DESCRIPTOR.message_types_by_name['ThreePointFavorite']
_THREEPOINTITEM = DESCRIPTOR.message_types_by_name['ThreePointItem']
_THREEPOINTSHARE = DESCRIPTOR.message_types_by_name['ThreePointShare']
_THREEPOINTSHARECHANNEL = DESCRIPTOR.message_types_by_name['ThreePointShareChannel']
_THREEPOINTWAIT = DESCRIPTOR.message_types_by_name['ThreePointWait']
_TOPICBUTTON = DESCRIPTOR.message_types_by_name['TopicButton']
_TOPICLIST = DESCRIPTOR.message_types_by_name['TopicList']
_TOPICLISTITEM = DESCRIPTOR.message_types_by_name['TopicListItem']
_UNFOLLOW = DESCRIPTOR.message_types_by_name['Unfollow']
_UNFOLLOWUSERITEM = DESCRIPTOR.message_types_by_name['UnfollowUserItem']
_UPLISTITEM = DESCRIPTOR.message_types_by_name['UpListItem']
_UPLISTMORELABEL = DESCRIPTOR.message_types_by_name['UpListMoreLabel']
_USERINFO = DESCRIPTOR.message_types_by_name['UserInfo']
_USERITEMSTYLE = DESCRIPTOR.message_types_by_name['UserItemStyle']
_USERPENDANT = DESCRIPTOR.message_types_by_name['UserPendant']
_VIDEOBADGE = DESCRIPTOR.message_types_by_name['VideoBadge']
_VIPINFO = DESCRIPTOR.message_types_by_name['VipInfo']
_VIPLABEL = DESCRIPTOR.message_types_by_name['VipLabel']
_WEIGHT = DESCRIPTOR.message_types_by_name['Weight']
_WEIGHTBUTTON = DESCRIPTOR.message_types_by_name['WeightButton']
_WEIGHTDISLIKE = DESCRIPTOR.message_types_by_name['WeightDislike']
_WEIGHTITEM = DESCRIPTOR.message_types_by_name['WeightItem']
AdParam = _reflection.GeneratedProtocolMessageType('AdParam', (_message.Message,), {
  'DESCRIPTOR' : _ADPARAM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdParam)
  })
_sym_db.RegisterMessage(AdParam)

AdditionCommon = _reflection.GeneratedProtocolMessageType('AdditionCommon', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONCOMMON,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionCommon)
  })
_sym_db.RegisterMessage(AdditionCommon)

AdditionEsport = _reflection.GeneratedProtocolMessageType('AdditionEsport', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONESPORT,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionEsport)
  })
_sym_db.RegisterMessage(AdditionEsport)

AdditionEsportMoba = _reflection.GeneratedProtocolMessageType('AdditionEsportMoba', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONESPORTMOBA,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionEsportMoba)
  })
_sym_db.RegisterMessage(AdditionEsportMoba)

AdditionEsportMobaStatus = _reflection.GeneratedProtocolMessageType('AdditionEsportMobaStatus', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONESPORTMOBASTATUS,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionEsportMobaStatus)
  })
_sym_db.RegisterMessage(AdditionEsportMobaStatus)

AdditionEsportMobaStatusDesc = _reflection.GeneratedProtocolMessageType('AdditionEsportMobaStatusDesc', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONESPORTMOBASTATUSDESC,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionEsportMobaStatusDesc)
  })
_sym_db.RegisterMessage(AdditionEsportMobaStatusDesc)

AdditionGoods = _reflection.GeneratedProtocolMessageType('AdditionGoods', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONGOODS,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionGoods)
  })
_sym_db.RegisterMessage(AdditionGoods)

AdditionUP = _reflection.GeneratedProtocolMessageType('AdditionUP', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONUP,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionUP)
  })
_sym_db.RegisterMessage(AdditionUP)

AdditionUgc = _reflection.GeneratedProtocolMessageType('AdditionUgc', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONUGC,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionUgc)
  })
_sym_db.RegisterMessage(AdditionUgc)

AdditionVote = _reflection.GeneratedProtocolMessageType('AdditionVote', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionVote)
  })
_sym_db.RegisterMessage(AdditionVote)

AdditionVote2 = _reflection.GeneratedProtocolMessageType('AdditionVote2', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTE2,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionVote2)
  })
_sym_db.RegisterMessage(AdditionVote2)

AdditionVoteDefaule = _reflection.GeneratedProtocolMessageType('AdditionVoteDefaule', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTEDEFAULE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionVoteDefaule)
  })
_sym_db.RegisterMessage(AdditionVoteDefaule)

AdditionVotePic = _reflection.GeneratedProtocolMessageType('AdditionVotePic', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTEPIC,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionVotePic)
  })
_sym_db.RegisterMessage(AdditionVotePic)

AdditionVotePicItem = _reflection.GeneratedProtocolMessageType('AdditionVotePicItem', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTEPICITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionVotePicItem)
  })
_sym_db.RegisterMessage(AdditionVotePicItem)

AdditionVoteWord = _reflection.GeneratedProtocolMessageType('AdditionVoteWord', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTEWORD,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionVoteWord)
  })
_sym_db.RegisterMessage(AdditionVoteWord)

AdditionVoteWordItem = _reflection.GeneratedProtocolMessageType('AdditionVoteWordItem', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTEWORDITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionVoteWordItem)
  })
_sym_db.RegisterMessage(AdditionVoteWordItem)

AdditionalActSkin = _reflection.GeneratedProtocolMessageType('AdditionalActSkin', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALACTSKIN,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionalActSkin)
  })
_sym_db.RegisterMessage(AdditionalActSkin)

AdditionalButton = _reflection.GeneratedProtocolMessageType('AdditionalButton', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALBUTTON,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionalButton)
  })
_sym_db.RegisterMessage(AdditionalButton)

AdditionalButtonInteractive = _reflection.GeneratedProtocolMessageType('AdditionalButtonInteractive', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALBUTTONINTERACTIVE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionalButtonInteractive)
  })
_sym_db.RegisterMessage(AdditionalButtonInteractive)

AdditionalButtonStyle = _reflection.GeneratedProtocolMessageType('AdditionalButtonStyle', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALBUTTONSTYLE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionalButtonStyle)
  })
_sym_db.RegisterMessage(AdditionalButtonStyle)

AdditionalPGC = _reflection.GeneratedProtocolMessageType('AdditionalPGC', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALPGC,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.AdditionalPGC)
  })
_sym_db.RegisterMessage(AdditionalPGC)

CardVideoDynList = _reflection.GeneratedProtocolMessageType('CardVideoDynList', (_message.Message,), {
  'DESCRIPTOR' : _CARDVIDEODYNLIST,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.CardVideoDynList)
  })
_sym_db.RegisterMessage(CardVideoDynList)

CardVideoFollowList = _reflection.GeneratedProtocolMessageType('CardVideoFollowList', (_message.Message,), {
  'DESCRIPTOR' : _CARDVIDEOFOLLOWLIST,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.CardVideoFollowList)
  })
_sym_db.RegisterMessage(CardVideoFollowList)

CardVideoUpList = _reflection.GeneratedProtocolMessageType('CardVideoUpList', (_message.Message,), {
  'DESCRIPTOR' : _CARDVIDEOUPLIST,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.CardVideoUpList)
  })
_sym_db.RegisterMessage(CardVideoUpList)

CmtShowItem = _reflection.GeneratedProtocolMessageType('CmtShowItem', (_message.Message,), {
  'DESCRIPTOR' : _CMTSHOWITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.CmtShowItem)
  })
_sym_db.RegisterMessage(CmtShowItem)

DecoCardFan = _reflection.GeneratedProtocolMessageType('DecoCardFan', (_message.Message,), {
  'DESCRIPTOR' : _DECOCARDFAN,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DecoCardFan)
  })
_sym_db.RegisterMessage(DecoCardFan)

DecorateCard = _reflection.GeneratedProtocolMessageType('DecorateCard', (_message.Message,), {
  'DESCRIPTOR' : _DECORATECARD,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DecorateCard)
  })
_sym_db.RegisterMessage(DecorateCard)

Description = _reflection.GeneratedProtocolMessageType('Description', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIPTION,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.Description)
  })
_sym_db.RegisterMessage(Description)

Dimension = _reflection.GeneratedProtocolMessageType('Dimension', (_message.Message,), {
  'DESCRIPTOR' : _DIMENSION,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.Dimension)
  })
_sym_db.RegisterMessage(Dimension)

DynAdditionCommonFollowReply = _reflection.GeneratedProtocolMessageType('DynAdditionCommonFollowReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNADDITIONCOMMONFOLLOWREPLY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynAdditionCommonFollowReply)
  })
_sym_db.RegisterMessage(DynAdditionCommonFollowReply)

DynAdditionCommonFollowReq = _reflection.GeneratedProtocolMessageType('DynAdditionCommonFollowReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNADDITIONCOMMONFOLLOWREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynAdditionCommonFollowReq)
  })
_sym_db.RegisterMessage(DynAdditionCommonFollowReq)

DynAllPersonalReply = _reflection.GeneratedProtocolMessageType('DynAllPersonalReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNALLPERSONALREPLY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynAllPersonalReply)
  })
_sym_db.RegisterMessage(DynAllPersonalReply)

DynAllPersonalReq = _reflection.GeneratedProtocolMessageType('DynAllPersonalReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNALLPERSONALREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynAllPersonalReq)
  })
_sym_db.RegisterMessage(DynAllPersonalReq)

DynAllReply = _reflection.GeneratedProtocolMessageType('DynAllReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNALLREPLY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynAllReply)
  })
_sym_db.RegisterMessage(DynAllReply)

DynAllReq = _reflection.GeneratedProtocolMessageType('DynAllReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNALLREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynAllReq)
  })
_sym_db.RegisterMessage(DynAllReq)

DynAllUpdOffsetReq = _reflection.GeneratedProtocolMessageType('DynAllUpdOffsetReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNALLUPDOFFSETREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynAllUpdOffsetReq)
  })
_sym_db.RegisterMessage(DynAllUpdOffsetReq)

DynDetailReply = _reflection.GeneratedProtocolMessageType('DynDetailReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNDETAILREPLY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynDetailReply)
  })
_sym_db.RegisterMessage(DynDetailReply)

DynDetailsReq = _reflection.GeneratedProtocolMessageType('DynDetailsReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNDETAILSREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynDetailsReq)
  })
_sym_db.RegisterMessage(DynDetailsReq)

DynFakeCardReply = _reflection.GeneratedProtocolMessageType('DynFakeCardReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNFAKECARDREPLY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynFakeCardReply)
  })
_sym_db.RegisterMessage(DynFakeCardReply)

DynFakeCardReq = _reflection.GeneratedProtocolMessageType('DynFakeCardReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNFAKECARDREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynFakeCardReq)
  })
_sym_db.RegisterMessage(DynFakeCardReq)

DynMixUpListViewMoreReply = _reflection.GeneratedProtocolMessageType('DynMixUpListViewMoreReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNMIXUPLISTVIEWMOREREPLY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynMixUpListViewMoreReply)
  })
_sym_db.RegisterMessage(DynMixUpListViewMoreReply)

DynMixUpListViewMoreReq = _reflection.GeneratedProtocolMessageType('DynMixUpListViewMoreReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNMIXUPLISTVIEWMOREREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynMixUpListViewMoreReq)
  })
_sym_db.RegisterMessage(DynMixUpListViewMoreReq)

DynRcmdUpExchangeReply = _reflection.GeneratedProtocolMessageType('DynRcmdUpExchangeReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNRCMDUPEXCHANGEREPLY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynRcmdUpExchangeReply)
  })
_sym_db.RegisterMessage(DynRcmdUpExchangeReply)

DynRcmdUpExchangeReq = _reflection.GeneratedProtocolMessageType('DynRcmdUpExchangeReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNRCMDUPEXCHANGEREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynRcmdUpExchangeReq)
  })
_sym_db.RegisterMessage(DynRcmdUpExchangeReq)

DynThumbReq = _reflection.GeneratedProtocolMessageType('DynThumbReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNTHUMBREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynThumbReq)
  })
_sym_db.RegisterMessage(DynThumbReq)

DynVideoPersonalReply = _reflection.GeneratedProtocolMessageType('DynVideoPersonalReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOPERSONALREPLY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynVideoPersonalReply)
  })
_sym_db.RegisterMessage(DynVideoPersonalReply)

DynVideoPersonalReq = _reflection.GeneratedProtocolMessageType('DynVideoPersonalReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOPERSONALREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynVideoPersonalReq)
  })
_sym_db.RegisterMessage(DynVideoPersonalReq)

DynVideoReply = _reflection.GeneratedProtocolMessageType('DynVideoReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOREPLY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynVideoReply)
  })
_sym_db.RegisterMessage(DynVideoReply)

DynVideoReq = _reflection.GeneratedProtocolMessageType('DynVideoReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynVideoReq)
  })
_sym_db.RegisterMessage(DynVideoReq)

DynVideoUpdOffsetReq = _reflection.GeneratedProtocolMessageType('DynVideoUpdOffsetReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOUPDOFFSETREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynVideoUpdOffsetReq)
  })
_sym_db.RegisterMessage(DynVideoUpdOffsetReq)

DynVoteReply = _reflection.GeneratedProtocolMessageType('DynVoteReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNVOTEREPLY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynVoteReply)
  })
_sym_db.RegisterMessage(DynVoteReply)

DynVoteReq = _reflection.GeneratedProtocolMessageType('DynVoteReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNVOTEREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynVoteReq)
  })
_sym_db.RegisterMessage(DynVoteReq)

DynamicItem = _reflection.GeneratedProtocolMessageType('DynamicItem', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynamicItem)
  })
_sym_db.RegisterMessage(DynamicItem)

DynamicList = _reflection.GeneratedProtocolMessageType('DynamicList', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICLIST,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.DynamicList)
  })
_sym_db.RegisterMessage(DynamicList)

ExtInfoCommon = _reflection.GeneratedProtocolMessageType('ExtInfoCommon', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOCOMMON,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ExtInfoCommon)
  })
_sym_db.RegisterMessage(ExtInfoCommon)

ExtInfoGame = _reflection.GeneratedProtocolMessageType('ExtInfoGame', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOGAME,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ExtInfoGame)
  })
_sym_db.RegisterMessage(ExtInfoGame)

ExtInfoHot = _reflection.GeneratedProtocolMessageType('ExtInfoHot', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOHOT,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ExtInfoHot)
  })
_sym_db.RegisterMessage(ExtInfoHot)

ExtInfoLBS = _reflection.GeneratedProtocolMessageType('ExtInfoLBS', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOLBS,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ExtInfoLBS)
  })
_sym_db.RegisterMessage(ExtInfoLBS)

ExtInfoOGV = _reflection.GeneratedProtocolMessageType('ExtInfoOGV', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOOGV,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ExtInfoOGV)
  })
_sym_db.RegisterMessage(ExtInfoOGV)

ExtInfoTopic = _reflection.GeneratedProtocolMessageType('ExtInfoTopic', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOTOPIC,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ExtInfoTopic)
  })
_sym_db.RegisterMessage(ExtInfoTopic)

Extend = _reflection.GeneratedProtocolMessageType('Extend', (_message.Message,), {
  'DESCRIPTOR' : _EXTEND,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.Extend)
  })
_sym_db.RegisterMessage(Extend)

ExtendReply = _reflection.GeneratedProtocolMessageType('ExtendReply', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDREPLY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ExtendReply)
  })
_sym_db.RegisterMessage(ExtendReply)

ExtendReplyParam = _reflection.GeneratedProtocolMessageType('ExtendReplyParam', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDREPLYPARAM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ExtendReplyParam)
  })
_sym_db.RegisterMessage(ExtendReplyParam)

FollowListItem = _reflection.GeneratedProtocolMessageType('FollowListItem', (_message.Message,), {
  'DESCRIPTOR' : _FOLLOWLISTITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.FollowListItem)
  })
_sym_db.RegisterMessage(FollowListItem)

GoodsItem = _reflection.GeneratedProtocolMessageType('GoodsItem', (_message.Message,), {
  'DESCRIPTOR' : _GOODSITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.GoodsItem)
  })
_sym_db.RegisterMessage(GoodsItem)

HighlightText = _reflection.GeneratedProtocolMessageType('HighlightText', (_message.Message,), {
  'DESCRIPTOR' : _HIGHLIGHTTEXT,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.HighlightText)
  })
_sym_db.RegisterMessage(HighlightText)

InfoOGV = _reflection.GeneratedProtocolMessageType('InfoOGV', (_message.Message,), {
  'DESCRIPTOR' : _INFOOGV,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.InfoOGV)
  })
_sym_db.RegisterMessage(InfoOGV)

InteractionItem = _reflection.GeneratedProtocolMessageType('InteractionItem', (_message.Message,), {
  'DESCRIPTOR' : _INTERACTIONITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.InteractionItem)
  })
_sym_db.RegisterMessage(InteractionItem)

LikeAnimation = _reflection.GeneratedProtocolMessageType('LikeAnimation', (_message.Message,), {
  'DESCRIPTOR' : _LIKEANIMATION,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.LikeAnimation)
  })
_sym_db.RegisterMessage(LikeAnimation)

LikeInfo = _reflection.GeneratedProtocolMessageType('LikeInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIKEINFO,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.LikeInfo)
  })
_sym_db.RegisterMessage(LikeInfo)

LikeUser = _reflection.GeneratedProtocolMessageType('LikeUser', (_message.Message,), {
  'DESCRIPTOR' : _LIKEUSER,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.LikeUser)
  })
_sym_db.RegisterMessage(LikeUser)

LiveInfo = _reflection.GeneratedProtocolMessageType('LiveInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIVEINFO,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.LiveInfo)
  })
_sym_db.RegisterMessage(LiveInfo)

MatchTeam = _reflection.GeneratedProtocolMessageType('MatchTeam', (_message.Message,), {
  'DESCRIPTOR' : _MATCHTEAM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MatchTeam)
  })
_sym_db.RegisterMessage(MatchTeam)

MdlDynApplet = _reflection.GeneratedProtocolMessageType('MdlDynApplet', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNAPPLET,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynApplet)
  })
_sym_db.RegisterMessage(MdlDynApplet)

MdlDynArchive = _reflection.GeneratedProtocolMessageType('MdlDynArchive', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNARCHIVE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynArchive)
  })
_sym_db.RegisterMessage(MdlDynArchive)

MdlDynArticle = _reflection.GeneratedProtocolMessageType('MdlDynArticle', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNARTICLE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynArticle)
  })
_sym_db.RegisterMessage(MdlDynArticle)

MdlDynCommon = _reflection.GeneratedProtocolMessageType('MdlDynCommon', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNCOMMON,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynCommon)
  })
_sym_db.RegisterMessage(MdlDynCommon)

MdlDynCourBatch = _reflection.GeneratedProtocolMessageType('MdlDynCourBatch', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNCOURBATCH,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynCourBatch)
  })
_sym_db.RegisterMessage(MdlDynCourBatch)

MdlDynCourSeason = _reflection.GeneratedProtocolMessageType('MdlDynCourSeason', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNCOURSEASON,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynCourSeason)
  })
_sym_db.RegisterMessage(MdlDynCourSeason)

MdlDynDraw = _reflection.GeneratedProtocolMessageType('MdlDynDraw', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNDRAW,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynDraw)
  })
_sym_db.RegisterMessage(MdlDynDraw)

MdlDynDrawItem = _reflection.GeneratedProtocolMessageType('MdlDynDrawItem', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNDRAWITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynDrawItem)
  })
_sym_db.RegisterMessage(MdlDynDrawItem)

MdlDynDrawTag = _reflection.GeneratedProtocolMessageType('MdlDynDrawTag', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNDRAWTAG,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynDrawTag)
  })
_sym_db.RegisterMessage(MdlDynDrawTag)

MdlDynDrawTagItem = _reflection.GeneratedProtocolMessageType('MdlDynDrawTagItem', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNDRAWTAGITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynDrawTagItem)
  })
_sym_db.RegisterMessage(MdlDynDrawTagItem)

MdlDynForward = _reflection.GeneratedProtocolMessageType('MdlDynForward', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNFORWARD,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynForward)
  })
_sym_db.RegisterMessage(MdlDynForward)

MdlDynLive = _reflection.GeneratedProtocolMessageType('MdlDynLive', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNLIVE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynLive)
  })
_sym_db.RegisterMessage(MdlDynLive)

MdlDynLiveRcmd = _reflection.GeneratedProtocolMessageType('MdlDynLiveRcmd', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNLIVERCMD,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynLiveRcmd)
  })
_sym_db.RegisterMessage(MdlDynLiveRcmd)

MdlDynMedialist = _reflection.GeneratedProtocolMessageType('MdlDynMedialist', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNMEDIALIST,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynMedialist)
  })
_sym_db.RegisterMessage(MdlDynMedialist)

MdlDynMusic = _reflection.GeneratedProtocolMessageType('MdlDynMusic', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNMUSIC,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynMusic)
  })
_sym_db.RegisterMessage(MdlDynMusic)

MdlDynPGC = _reflection.GeneratedProtocolMessageType('MdlDynPGC', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNPGC,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynPGC)
  })
_sym_db.RegisterMessage(MdlDynPGC)

MdlDynSubscription = _reflection.GeneratedProtocolMessageType('MdlDynSubscription', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNSUBSCRIPTION,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynSubscription)
  })
_sym_db.RegisterMessage(MdlDynSubscription)

MdlDynSubscriptionNew = _reflection.GeneratedProtocolMessageType('MdlDynSubscriptionNew', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNSUBSCRIPTIONNEW,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynSubscriptionNew)
  })
_sym_db.RegisterMessage(MdlDynSubscriptionNew)

MdlDynUGCSeason = _reflection.GeneratedProtocolMessageType('MdlDynUGCSeason', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNUGCSEASON,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MdlDynUGCSeason)
  })
_sym_db.RegisterMessage(MdlDynUGCSeason)

MixUpListItem = _reflection.GeneratedProtocolMessageType('MixUpListItem', (_message.Message,), {
  'DESCRIPTOR' : _MIXUPLISTITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MixUpListItem)
  })
_sym_db.RegisterMessage(MixUpListItem)

MixUpListLiveItem = _reflection.GeneratedProtocolMessageType('MixUpListLiveItem', (_message.Message,), {
  'DESCRIPTOR' : _MIXUPLISTLIVEITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.MixUpListLiveItem)
  })
_sym_db.RegisterMessage(MixUpListLiveItem)

Module = _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), {
  'DESCRIPTOR' : _MODULE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.Module)
  })
_sym_db.RegisterMessage(Module)

ModuleAd = _reflection.GeneratedProtocolMessageType('ModuleAd', (_message.Message,), {
  'DESCRIPTOR' : _MODULEAD,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleAd)
  })
_sym_db.RegisterMessage(ModuleAd)

ModuleAdditional = _reflection.GeneratedProtocolMessageType('ModuleAdditional', (_message.Message,), {
  'DESCRIPTOR' : _MODULEADDITIONAL,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleAdditional)
  })
_sym_db.RegisterMessage(ModuleAdditional)

ModuleAuthor = _reflection.GeneratedProtocolMessageType('ModuleAuthor', (_message.Message,), {
  'DESCRIPTOR' : _MODULEAUTHOR,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleAuthor)
  })
_sym_db.RegisterMessage(ModuleAuthor)

ModuleAuthorBadgeButton = _reflection.GeneratedProtocolMessageType('ModuleAuthorBadgeButton', (_message.Message,), {
  'DESCRIPTOR' : _MODULEAUTHORBADGEBUTTON,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleAuthorBadgeButton)
  })
_sym_db.RegisterMessage(ModuleAuthorBadgeButton)

ModuleAuthorForward = _reflection.GeneratedProtocolMessageType('ModuleAuthorForward', (_message.Message,), {
  'DESCRIPTOR' : _MODULEAUTHORFORWARD,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleAuthorForward)
  })
_sym_db.RegisterMessage(ModuleAuthorForward)

ModuleAuthorForwardTitle = _reflection.GeneratedProtocolMessageType('ModuleAuthorForwardTitle', (_message.Message,), {
  'DESCRIPTOR' : _MODULEAUTHORFORWARDTITLE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleAuthorForwardTitle)
  })
_sym_db.RegisterMessage(ModuleAuthorForwardTitle)

ModuleBanner = _reflection.GeneratedProtocolMessageType('ModuleBanner', (_message.Message,), {
  'DESCRIPTOR' : _MODULEBANNER,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleBanner)
  })
_sym_db.RegisterMessage(ModuleBanner)

ModuleBannerUser = _reflection.GeneratedProtocolMessageType('ModuleBannerUser', (_message.Message,), {
  'DESCRIPTOR' : _MODULEBANNERUSER,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleBannerUser)
  })
_sym_db.RegisterMessage(ModuleBannerUser)

ModuleBannerUserItem = _reflection.GeneratedProtocolMessageType('ModuleBannerUserItem', (_message.Message,), {
  'DESCRIPTOR' : _MODULEBANNERUSERITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleBannerUserItem)
  })
_sym_db.RegisterMessage(ModuleBannerUserItem)

ModuleButtom = _reflection.GeneratedProtocolMessageType('ModuleButtom', (_message.Message,), {
  'DESCRIPTOR' : _MODULEBUTTOM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleButtom)
  })
_sym_db.RegisterMessage(ModuleButtom)

ModuleComment = _reflection.GeneratedProtocolMessageType('ModuleComment', (_message.Message,), {
  'DESCRIPTOR' : _MODULECOMMENT,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleComment)
  })
_sym_db.RegisterMessage(ModuleComment)

ModuleDesc = _reflection.GeneratedProtocolMessageType('ModuleDesc', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDESC,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleDesc)
  })
_sym_db.RegisterMessage(ModuleDesc)

ModuleDescGoods = _reflection.GeneratedProtocolMessageType('ModuleDescGoods', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDESCGOODS,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleDescGoods)
  })
_sym_db.RegisterMessage(ModuleDescGoods)

ModuleDispute = _reflection.GeneratedProtocolMessageType('ModuleDispute', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDISPUTE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleDispute)
  })
_sym_db.RegisterMessage(ModuleDispute)

ModuleDynamic = _reflection.GeneratedProtocolMessageType('ModuleDynamic', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDYNAMIC,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleDynamic)
  })
_sym_db.RegisterMessage(ModuleDynamic)

ModuleExtend = _reflection.GeneratedProtocolMessageType('ModuleExtend', (_message.Message,), {
  'DESCRIPTOR' : _MODULEEXTEND,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleExtend)
  })
_sym_db.RegisterMessage(ModuleExtend)

ModuleExtendItem = _reflection.GeneratedProtocolMessageType('ModuleExtendItem', (_message.Message,), {
  'DESCRIPTOR' : _MODULEEXTENDITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleExtendItem)
  })
_sym_db.RegisterMessage(ModuleExtendItem)

ModuleFold = _reflection.GeneratedProtocolMessageType('ModuleFold', (_message.Message,), {
  'DESCRIPTOR' : _MODULEFOLD,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleFold)
  })
_sym_db.RegisterMessage(ModuleFold)

ModuleInteraction = _reflection.GeneratedProtocolMessageType('ModuleInteraction', (_message.Message,), {
  'DESCRIPTOR' : _MODULEINTERACTION,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleInteraction)
  })
_sym_db.RegisterMessage(ModuleInteraction)

ModuleItemNull = _reflection.GeneratedProtocolMessageType('ModuleItemNull', (_message.Message,), {
  'DESCRIPTOR' : _MODULEITEMNULL,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleItemNull)
  })
_sym_db.RegisterMessage(ModuleItemNull)

ModuleLikeUser = _reflection.GeneratedProtocolMessageType('ModuleLikeUser', (_message.Message,), {
  'DESCRIPTOR' : _MODULELIKEUSER,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleLikeUser)
  })
_sym_db.RegisterMessage(ModuleLikeUser)

ModuleRecommend = _reflection.GeneratedProtocolMessageType('ModuleRecommend', (_message.Message,), {
  'DESCRIPTOR' : _MODULERECOMMEND,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleRecommend)
  })
_sym_db.RegisterMessage(ModuleRecommend)

ModuleShareInfo = _reflection.GeneratedProtocolMessageType('ModuleShareInfo', (_message.Message,), {
  'DESCRIPTOR' : _MODULESHAREINFO,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleShareInfo)
  })
_sym_db.RegisterMessage(ModuleShareInfo)

ModuleStat = _reflection.GeneratedProtocolMessageType('ModuleStat', (_message.Message,), {
  'DESCRIPTOR' : _MODULESTAT,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleStat)
  })
_sym_db.RegisterMessage(ModuleStat)

ModuleTop = _reflection.GeneratedProtocolMessageType('ModuleTop', (_message.Message,), {
  'DESCRIPTOR' : _MODULETOP,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ModuleTop)
  })
_sym_db.RegisterMessage(ModuleTop)

Nameplate = _reflection.GeneratedProtocolMessageType('Nameplate', (_message.Message,), {
  'DESCRIPTOR' : _NAMEPLATE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.Nameplate)
  })
_sym_db.RegisterMessage(Nameplate)

NewEP = _reflection.GeneratedProtocolMessageType('NewEP', (_message.Message,), {
  'DESCRIPTOR' : _NEWEP,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.NewEP)
  })
_sym_db.RegisterMessage(NewEP)

NoReply = _reflection.GeneratedProtocolMessageType('NoReply', (_message.Message,), {
  'DESCRIPTOR' : _NOREPLY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.NoReply)
  })
_sym_db.RegisterMessage(NoReply)

NoReq = _reflection.GeneratedProtocolMessageType('NoReq', (_message.Message,), {
  'DESCRIPTOR' : _NOREQ,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.NoReq)
  })
_sym_db.RegisterMessage(NoReq)

OfficialVerify = _reflection.GeneratedProtocolMessageType('OfficialVerify', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALVERIFY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.OfficialVerify)
  })
_sym_db.RegisterMessage(OfficialVerify)

PGCSeason = _reflection.GeneratedProtocolMessageType('PGCSeason', (_message.Message,), {
  'DESCRIPTOR' : _PGCSEASON,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.PGCSeason)
  })
_sym_db.RegisterMessage(PGCSeason)

PlayerArgs = _reflection.GeneratedProtocolMessageType('PlayerArgs', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERARGS,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.PlayerArgs)
  })
_sym_db.RegisterMessage(PlayerArgs)

PlayurlParam = _reflection.GeneratedProtocolMessageType('PlayurlParam', (_message.Message,), {
  'DESCRIPTOR' : _PLAYURLPARAM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.PlayurlParam)
  })
_sym_db.RegisterMessage(PlayurlParam)

RcmdUPsParam = _reflection.GeneratedProtocolMessageType('RcmdUPsParam', (_message.Message,), {
  'DESCRIPTOR' : _RCMDUPSPARAM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.RcmdUPsParam)
  })
_sym_db.RegisterMessage(RcmdUPsParam)

Relation = _reflection.GeneratedProtocolMessageType('Relation', (_message.Message,), {
  'DESCRIPTOR' : _RELATION,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.Relation)
  })
_sym_db.RegisterMessage(Relation)

ShareChannel = _reflection.GeneratedProtocolMessageType('ShareChannel', (_message.Message,), {
  'DESCRIPTOR' : _SHARECHANNEL,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ShareChannel)
  })
_sym_db.RegisterMessage(ShareChannel)

SortType = _reflection.GeneratedProtocolMessageType('SortType', (_message.Message,), {
  'DESCRIPTOR' : _SORTTYPE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.SortType)
  })
_sym_db.RegisterMessage(SortType)

ThreePointAttention = _reflection.GeneratedProtocolMessageType('ThreePointAttention', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTATTENTION,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ThreePointAttention)
  })
_sym_db.RegisterMessage(ThreePointAttention)

ThreePointAutoPlay = _reflection.GeneratedProtocolMessageType('ThreePointAutoPlay', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTAUTOPLAY,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ThreePointAutoPlay)
  })
_sym_db.RegisterMessage(ThreePointAutoPlay)

ThreePointDefault = _reflection.GeneratedProtocolMessageType('ThreePointDefault', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTDEFAULT,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ThreePointDefault)
  })
_sym_db.RegisterMessage(ThreePointDefault)

ThreePointDislike = _reflection.GeneratedProtocolMessageType('ThreePointDislike', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTDISLIKE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ThreePointDislike)
  })
_sym_db.RegisterMessage(ThreePointDislike)

ThreePointFavorite = _reflection.GeneratedProtocolMessageType('ThreePointFavorite', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTFAVORITE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ThreePointFavorite)
  })
_sym_db.RegisterMessage(ThreePointFavorite)

ThreePointItem = _reflection.GeneratedProtocolMessageType('ThreePointItem', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ThreePointItem)
  })
_sym_db.RegisterMessage(ThreePointItem)

ThreePointShare = _reflection.GeneratedProtocolMessageType('ThreePointShare', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTSHARE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ThreePointShare)
  })
_sym_db.RegisterMessage(ThreePointShare)

ThreePointShareChannel = _reflection.GeneratedProtocolMessageType('ThreePointShareChannel', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTSHARECHANNEL,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ThreePointShareChannel)
  })
_sym_db.RegisterMessage(ThreePointShareChannel)

ThreePointWait = _reflection.GeneratedProtocolMessageType('ThreePointWait', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTWAIT,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.ThreePointWait)
  })
_sym_db.RegisterMessage(ThreePointWait)

TopicButton = _reflection.GeneratedProtocolMessageType('TopicButton', (_message.Message,), {
  'DESCRIPTOR' : _TOPICBUTTON,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.TopicButton)
  })
_sym_db.RegisterMessage(TopicButton)

TopicList = _reflection.GeneratedProtocolMessageType('TopicList', (_message.Message,), {
  'DESCRIPTOR' : _TOPICLIST,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.TopicList)
  })
_sym_db.RegisterMessage(TopicList)

TopicListItem = _reflection.GeneratedProtocolMessageType('TopicListItem', (_message.Message,), {
  'DESCRIPTOR' : _TOPICLISTITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.TopicListItem)
  })
_sym_db.RegisterMessage(TopicListItem)

Unfollow = _reflection.GeneratedProtocolMessageType('Unfollow', (_message.Message,), {
  'DESCRIPTOR' : _UNFOLLOW,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.Unfollow)
  })
_sym_db.RegisterMessage(Unfollow)

UnfollowUserItem = _reflection.GeneratedProtocolMessageType('UnfollowUserItem', (_message.Message,), {
  'DESCRIPTOR' : _UNFOLLOWUSERITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.UnfollowUserItem)
  })
_sym_db.RegisterMessage(UnfollowUserItem)

UpListItem = _reflection.GeneratedProtocolMessageType('UpListItem', (_message.Message,), {
  'DESCRIPTOR' : _UPLISTITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.UpListItem)
  })
_sym_db.RegisterMessage(UpListItem)

UpListMoreLabel = _reflection.GeneratedProtocolMessageType('UpListMoreLabel', (_message.Message,), {
  'DESCRIPTOR' : _UPLISTMORELABEL,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.UpListMoreLabel)
  })
_sym_db.RegisterMessage(UpListMoreLabel)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERINFO,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.UserInfo)
  })
_sym_db.RegisterMessage(UserInfo)

UserItemStyle = _reflection.GeneratedProtocolMessageType('UserItemStyle', (_message.Message,), {
  'DESCRIPTOR' : _USERITEMSTYLE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.UserItemStyle)
  })
_sym_db.RegisterMessage(UserItemStyle)

UserPendant = _reflection.GeneratedProtocolMessageType('UserPendant', (_message.Message,), {
  'DESCRIPTOR' : _USERPENDANT,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.UserPendant)
  })
_sym_db.RegisterMessage(UserPendant)

VideoBadge = _reflection.GeneratedProtocolMessageType('VideoBadge', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOBADGE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.VideoBadge)
  })
_sym_db.RegisterMessage(VideoBadge)

VipInfo = _reflection.GeneratedProtocolMessageType('VipInfo', (_message.Message,), {
  'DESCRIPTOR' : _VIPINFO,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.VipInfo)
  })
_sym_db.RegisterMessage(VipInfo)

VipLabel = _reflection.GeneratedProtocolMessageType('VipLabel', (_message.Message,), {
  'DESCRIPTOR' : _VIPLABEL,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.VipLabel)
  })
_sym_db.RegisterMessage(VipLabel)

Weight = _reflection.GeneratedProtocolMessageType('Weight', (_message.Message,), {
  'DESCRIPTOR' : _WEIGHT,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.Weight)
  })
_sym_db.RegisterMessage(Weight)

WeightButton = _reflection.GeneratedProtocolMessageType('WeightButton', (_message.Message,), {
  'DESCRIPTOR' : _WEIGHTBUTTON,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.WeightButton)
  })
_sym_db.RegisterMessage(WeightButton)

WeightDislike = _reflection.GeneratedProtocolMessageType('WeightDislike', (_message.Message,), {
  'DESCRIPTOR' : _WEIGHTDISLIKE,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.WeightDislike)
  })
_sym_db.RegisterMessage(WeightDislike)

WeightItem = _reflection.GeneratedProtocolMessageType('WeightItem', (_message.Message,), {
  'DESCRIPTOR' : _WEIGHTITEM,
  '__module__' : 'bilibili.dynamic.gw.gateway_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.dynamic.gateway.WeightItem)
  })
_sym_db.RegisterMessage(WeightItem)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ADDBUTTONBGSTYLE._serialized_start=28369
  _ADDBUTTONBGSTYLE._serialized_end=28419
  _ADDBUTTONTYPE._serialized_start=28421
  _ADDBUTTONTYPE._serialized_end=28477
  _ADDITIONVOTESTATE._serialized_start=28479
  _ADDITIONVOTESTATE._serialized_end=28589
  _ADDITIONVOTETYPE._serialized_start=28592
  _ADDITIONVOTETYPE._serialized_end=28728
  _ADDITIONALBUTTONCLICKTYPE._serialized_start=28730
  _ADDITIONALBUTTONCLICKTYPE._serialized_end=28787
  _ADDITIONALBUTTONSTATUS._serialized_start=28789
  _ADDITIONALBUTTONSTATUS._serialized_end=28847
  _ADDITIONALTYPE._serialized_start=28850
  _ADDITIONALTYPE._serialized_end=29111
  _DESCTYPE._serialized_start=29114
  _DESCTYPE._serialized_end=29491
  _DISABLESTATE._serialized_start=29493
  _DISABLESTATE._serialized_end=29532
  _DYNEXTENDTYPE._serialized_start=29535
  _DYNEXTENDTYPE._serialized_end=29764
  _DYNMODULETYPE._serialized_start=29767
  _DYNMODULETYPE._serialized_end=30224
  _DYNURITYPE._serialized_start=30226
  _DYNURITYPE._serialized_end=30311
  _DYNAMICTYPE._serialized_start=30314
  _DYNAMICTYPE._serialized_end=30626
  _EMOJITYPE._serialized_start=30628
  _EMOJITYPE._serialized_end=30694
  _ESPACESTYLE._serialized_start=30696
  _ESPACESTYLE._serialized_end=30719
  _FOLDTYPE._serialized_start=30721
  _FOLDTYPE._serialized_end=30830
  _FOLLOWTYPE._serialized_start=30832
  _FOLLOWTYPE._serialized_end=30878
  _HIGHLIGHTTEXTSTYLE._serialized_start=30880
  _HIGHLIGHTTEXTSTYLE._serialized_end=30937
  _IMAGESTYLE._serialized_start=30939
  _IMAGESTYLE._serialized_end=30997
  _LIVESTATE._serialized_start=30999
  _LIVESTATE._serialized_end=31059
  _LOCALICONTYPE._serialized_start=31061
  _LOCALICONTYPE._serialized_end=31121
  _MDLDYNCOMMONTYPE._serialized_start=31123
  _MDLDYNCOMMONTYPE._serialized_end=31221
  _MDLDYNDRAWTAGTYPE._serialized_start=31224
  _MDLDYNDRAWTAGTYPE._serialized_end=31384
  _MDLDYNSUBSCRIPTIONNEWSTYLE._serialized_start=31387
  _MDLDYNSUBSCRIPTIONNEWSTYLE._serialized_end=31538
  _MEDIATYPE._serialized_start=31540
  _MEDIATYPE._serialized_end=31643
  _MODULEAUTHORBADGETYPE._serialized_start=31646
  _MODULEAUTHORBADGETYPE._serialized_end=31819
  _MODULEBANNERTYPE._serialized_start=31821
  _MODULEBANNERTYPE._serialized_end=31897
  _MODULEDYNAMICTYPE._serialized_start=31900
  _MODULEDYNAMICTYPE._serialized_end=32269
  _REFRESH._serialized_start=32271
  _REFRESH._serialized_end=32318
  _RELATIONSTATUS._serialized_start=32321
  _RELATIONSTATUS._serialized_end=32516
  _RESERVETYPE._serialized_start=32518
  _RESERVETYPE._serialized_end=32569
  _THREEPOINTATTENTIONSTATUS._serialized_start=32571
  _THREEPOINTATTENTIONSTATUS._serialized_end=32638
  _THREEPOINTTYPE._serialized_start=32641
  _THREEPOINTTYPE._serialized_end=32788
  _THUMBTYPE._serialized_start=32790
  _THUMBTYPE._serialized_end=32824
  _USERITEMTYPE._serialized_start=32827
  _USERITEMTYPE._serialized_end=32977
  _VIDEOSUBTYPE._serialized_start=32980
  _VIDEOSUBTYPE._serialized_end=33145
  _VIDEOTYPE._serialized_start=33147
  _VIDEOTYPE._serialized_end=33231
  _VOTESTATUS._serialized_start=33233
  _VOTESTATUS._serialized_end=33272
  _WEIGHTTYPE._serialized_start=33274
  _WEIGHTTYPE._serialized_end=33340
  _ADPARAM._serialized_start=90
  _ADPARAM._serialized_end=137
  _ADDITIONCOMMON._serialized_start=140
  _ADDITIONCOMMON._serialized_end=429
  _ADDITIONESPORT._serialized_start=432
  _ADDITIONESPORT._serialized_end=621
  _ADDITIONESPORTMOBA._serialized_start=624
  _ADDITIONESPORTMOBA._serialized_end=949
  _ADDITIONESPORTMOBASTATUS._serialized_start=952
  _ADDITIONESPORTMOBASTATUS._serialized_end=1143
  _ADDITIONESPORTMOBASTATUSDESC._serialized_start=1145
  _ADDITIONESPORTMOBASTATUSDESC._serialized_end=1226
  _ADDITIONGOODS._serialized_start=1229
  _ADDITIONGOODS._serialized_end=1388
  _ADDITIONUP._serialized_start=1391
  _ADDITIONUP._serialized_end=1679
  _ADDITIONUGC._serialized_start=1682
  _ADDITIONUGC._serialized_end=1855
  _ADDITIONVOTE._serialized_start=1857
  _ADDITIONVOTE._serialized_end=1955
  _ADDITIONVOTE2._serialized_start=1958
  _ADDITIONVOTE2._serialized_end=2610
  _ADDITIONVOTEDEFAULE._serialized_start=2612
  _ADDITIONVOTEDEFAULE._serialized_end=2648
  _ADDITIONVOTEPIC._serialized_start=2650
  _ADDITIONVOTEPIC._serialized_end=2728
  _ADDITIONVOTEPICITEM._serialized_start=2731
  _ADDITIONVOTEPICITEM._serialized_end=2871
  _ADDITIONVOTEWORD._serialized_start=2873
  _ADDITIONVOTEWORD._serialized_end=2953
  _ADDITIONVOTEWORDITEM._serialized_start=2955
  _ADDITIONVOTEWORDITEM._serialized_end=3081
  _ADDITIONALACTSKIN._serialized_start=3083
  _ADDITIONALACTSKIN._serialized_end=3156
  _ADDITIONALBUTTON._serialized_start=3159
  _ADDITIONALBUTTON._serialized_end=3588
  _ADDITIONALBUTTONINTERACTIVE._serialized_start=3590
  _ADDITIONALBUTTONINTERACTIVE._serialized_end=3682
  _ADDITIONALBUTTONSTYLE._serialized_start=3685
  _ADDITIONALBUTTONSTYLE._serialized_end=3946
  _ADDITIONALPGC._serialized_start=3949
  _ADDITIONALPGC._serialized_end=4218
  _CARDVIDEODYNLIST._serialized_start=4221
  _CARDVIDEODYNLIST._serialized_end=4379
  _CARDVIDEOFOLLOWLIST._serialized_start=4381
  _CARDVIDEOFOLLOWLIST._serialized_end=4481
  _CARDVIDEOUPLIST._serialized_start=4484
  _CARDVIDEOUPLIST._serialized_end=4772
  _CMTSHOWITEM._serialized_start=4774
  _CMTSHOWITEM._serialized_end=4845
  _DECOCARDFAN._serialized_start=4847
  _DECOCARDFAN._serialized_end=4927
  _DECORATECARD._serialized_start=4929
  _DECORATECARD._serialized_end=5043
  _DESCRIPTION._serialized_start=5046
  _DESCRIPTION._serialized_end=5340
  _DIMENSION._serialized_start=5342
  _DIMENSION._serialized_end=5400
  _DYNADDITIONCOMMONFOLLOWREPLY._serialized_start=5402
  _DYNADDITIONCOMMONFOLLOWREPLY._serialized_end=5498
  _DYNADDITIONCOMMONFOLLOWREQ._serialized_start=5501
  _DYNADDITIONCOMMONFOLLOWREQ._serialized_end=5630
  _DYNALLPERSONALREPLY._serialized_start=5633
  _DYNALLPERSONALREPLY._serialized_end=5816
  _DYNALLPERSONALREQ._serialized_start=5819
  _DYNALLPERSONALREQ._serialized_end=6081
  _DYNALLREPLY._serialized_start=6084
  _DYNALLREPLY._serialized_end=6329
  _DYNALLREQ._serialized_start=6332
  _DYNALLREQ._serialized_end=6773
  _DYNALLUPDOFFSETREQ._serialized_start=6775
  _DYNALLUPDOFFSETREQ._serialized_end=6853
  _DYNDETAILREPLY._serialized_start=6855
  _DYNDETAILREPLY._serialized_end=6924
  _DYNDETAILSREQ._serialized_start=6927
  _DYNDETAILSREQ._serialized_end=7105
  _DYNFAKECARDREPLY._serialized_start=7107
  _DYNFAKECARDREPLY._serialized_end=7178
  _DYNFAKECARDREQ._serialized_start=7180
  _DYNFAKECARDREQ._serialized_end=7213
  _DYNMIXUPLISTVIEWMOREREPLY._serialized_start=7216
  _DYNMIXUPLISTVIEWMOREREPLY._serialized_end=7441
  _DYNMIXUPLISTVIEWMOREREQ._serialized_start=7443
  _DYNMIXUPLISTVIEWMOREREQ._serialized_end=7487
  _DYNRCMDUPEXCHANGEREPLY._serialized_start=7489
  _DYNRCMDUPEXCHANGEREPLY._serialized_end=7567
  _DYNRCMDUPEXCHANGEREQ._serialized_start=7569
  _DYNRCMDUPEXCHANGEREQ._serialized_end=7637
  _DYNTHUMBREQ._serialized_start=7639
  _DYNTHUMBREQ._serialized_end=7763
  _DYNVIDEOPERSONALREPLY._serialized_start=7766
  _DYNVIDEOPERSONALREPLY._serialized_end=7951
  _DYNVIDEOPERSONALREQ._serialized_start=7954
  _DYNVIDEOPERSONALREQ._serialized_end=8218
  _DYNVIDEOREPLY._serialized_start=8221
  _DYNVIDEOREPLY._serialized_end=8442
  _DYNVIDEOREQ._serialized_start=8445
  _DYNVIDEOREQ._serialized_end=8751
  _DYNVIDEOUPDOFFSETREQ._serialized_start=8753
  _DYNVIDEOUPDOFFSETREQ._serialized_end=8833
  _DYNVOTEREPLY._serialized_start=8835
  _DYNVOTEREPLY._serialized_end=8919
  _DYNVOTEREQ._serialized_start=8922
  _DYNVOTEREQ._serialized_end=9055
  _DYNAMICITEM._serialized_start=9058
  _DYNAMICITEM._serialized_end=9306
  _DYNAMICLIST._serialized_start=9309
  _DYNAMICLIST._serialized_end=9462
  _EXTINFOCOMMON._serialized_start=9465
  _EXTINFOCOMMON._serialized_end=9692
  _EXTINFOGAME._serialized_start=9694
  _EXTINFOGAME._serialized_end=9749
  _EXTINFOHOT._serialized_start=9751
  _EXTINFOHOT._serialized_end=9805
  _EXTINFOLBS._serialized_start=9807
  _EXTINFOLBS._serialized_end=9879
  _EXTINFOOGV._serialized_start=9881
  _EXTINFOOGV._serialized_end=9946
  _EXTINFOTOPIC._serialized_start=9948
  _EXTINFOTOPIC._serialized_end=10004
  _EXTEND._serialized_start=10007
  _EXTEND._serialized_end=10543
  _EXTENDREPLY._serialized_start=10545
  _EXTENDREPLY._serialized_end=10631
  _EXTENDREPLYPARAM._serialized_start=10633
  _EXTENDREPLYPARAM._serialized_end=10679
  _FOLLOWLISTITEM._serialized_start=10682
  _FOLLOWLISTITEM._serialized_end=10841
  _GOODSITEM._serialized_start=10844
  _GOODSITEM._serialized_end=11102
  _HIGHLIGHTTEXT._serialized_start=11104
  _HIGHLIGHTTEXT._serialized_end=11199
  _INFOOGV._serialized_start=11201
  _INFOOGV._serialized_end=11272
  _INTERACTIONITEM._serialized_start=11275
  _INTERACTIONITEM._serialized_end=11459
  _LIKEANIMATION._serialized_start=11461
  _LIKEANIMATION._serialized_end=11540
  _LIKEINFO._serialized_start=11542
  _LIKEINFO._serialized_end=11629
  _LIKEUSER._serialized_start=11631
  _LIKEUSER._serialized_end=11682
  _LIVEINFO._serialized_start=11684
  _LIVEINFO._serialized_end=11783
  _MATCHTEAM._serialized_start=11785
  _MATCHTEAM._serialized_end=11873
  _MDLDYNAPPLET._serialized_start=11876
  _MDLDYNAPPLET._serialized_end=12015
  _MDLDYNARCHIVE._serialized_start=12018
  _MDLDYNARCHIVE._serialized_end=12757
  _MDLDYNARTICLE._serialized_start=12759
  _MDLDYNARTICLE._serialized_end=12879
  _MDLDYNCOMMON._serialized_start=12882
  _MDLDYNCOMMON._serialized_end=13128
  _MDLDYNCOURBATCH._serialized_start=13131
  _MDLDYNCOURBATCH._serialized_end=13295
  _MDLDYNCOURSEASON._serialized_start=13298
  _MDLDYNCOURSEASON._serialized_end=13461
  _MDLDYNDRAW._serialized_start=13463
  _MDLDYNDRAW._serialized_end=13557
  _MDLDYNDRAWITEM._serialized_start=13560
  _MDLDYNDRAWITEM._serialized_end=13689
  _MDLDYNDRAWTAG._serialized_start=13692
  _MDLDYNDRAWTAG._serialized_end=13825
  _MDLDYNDRAWTAGITEM._serialized_start=13828
  _MDLDYNDRAWTAGITEM._serialized_end=14009
  _MDLDYNFORWARD._serialized_start=14011
  _MDLDYNFORWARD._serialized_end=14094
  _MDLDYNLIVE._serialized_start=14097
  _MDLDYNLIVE._serialized_end=14378
  _MDLDYNLIVERCMD._serialized_start=14380
  _MDLDYNLIVERCMD._serialized_end=14474
  _MDLDYNMEDIALIST._serialized_start=14477
  _MDLDYNMEDIALIST._serialized_end=14641
  _MDLDYNMUSIC._serialized_start=14643
  _MDLDYNMUSIC._serialized_end=14757
  _MDLDYNPGC._serialized_start=14760
  _MDLDYNPGC._serialized_end=15406
  _MDLDYNSUBSCRIPTION._serialized_start=15409
  _MDLDYNSUBSCRIPTION._serialized_end=15584
  _MDLDYNSUBSCRIPTIONNEW._serialized_start=15587
  _MDLDYNSUBSCRIPTIONNEW._serialized_end=15828
  _MDLDYNUGCSEASON._serialized_start=15831
  _MDLDYNUGCSEASON._serialized_end=16159
  _MIXUPLISTITEM._serialized_start=16162
  _MIXUPLISTITEM._serialized_end=16493
  _MIXUPLISTLIVEITEM._serialized_start=16495
  _MIXUPLISTLIVEITEM._serialized_end=16560
  _MODULE._serialized_start=16563
  _MODULE._serialized_end=17987
  _MODULEAD._serialized_start=17989
  _MODULEAD._serialized_end=18108
  _MODULEADDITIONAL._serialized_start=18111
  _MODULEADDITIONAL._serialized_end=18660
  _MODULEAUTHOR._serialized_start=18663
  _MODULEAUTHOR._serialized_end=19165
  _MODULEAUTHORBADGEBUTTON._serialized_start=19167
  _MODULEAUTHORBADGEBUTTON._serialized_end=19248
  _MODULEAUTHORFORWARD._serialized_start=19251
  _MODULEAUTHORFORWARD._serialized_end=19543
  _MODULEAUTHORFORWARDTITLE._serialized_start=19545
  _MODULEAUTHORFORWARDTITLE._serialized_end=19598
  _MODULEBANNER._serialized_start=19601
  _MODULEBANNER._serialized_end=19800
  _MODULEBANNERUSER._serialized_start=19802
  _MODULEBANNERUSER._serialized_end=19882
  _MODULEBANNERUSERITEM._serialized_start=19885
  _MODULEBANNERUSERITEM._serialized_end=20201
  _MODULEBUTTOM._serialized_start=20203
  _MODULEBUTTOM._serialized_end=20276
  _MODULECOMMENT._serialized_start=20278
  _MODULECOMMENT._serialized_end=20353
  _MODULEDESC._serialized_start=20355
  _MODULEDESC._serialized_end=20452
  _MODULEDESCGOODS._serialized_start=20455
  _MODULEDESCGOODS._serialized_end=20640
  _MODULEDISPUTE._serialized_start=20642
  _MODULEDISPUTE._serialized_end=20699
  _MODULEDYNAMIC._serialized_start=20702
  _MODULEDYNAMIC._serialized_end=21845
  _MODULEEXTEND._serialized_start=21847
  _MODULEEXTEND._serialized_end=21934
  _MODULEEXTENDITEM._serialized_start=21937
  _MODULEEXTENDITEM._serialized_end=22404
  _MODULEFOLD._serialized_start=22407
  _MODULEFOLD._serialized_end=22562
  _MODULEINTERACTION._serialized_start=22564
  _MODULEINTERACTION._serialized_end=22652
  _MODULEITEMNULL._serialized_start=22654
  _MODULEITEMNULL._serialized_end=22698
  _MODULELIKEUSER._serialized_start=22700
  _MODULELIKEUSER._serialized_end=22794
  _MODULERECOMMEND._serialized_start=22797
  _MODULERECOMMEND._serialized_end=22931
  _MODULESHAREINFO._serialized_start=22934
  _MODULESHAREINFO._serialized_end=23078
  _MODULESTAT._serialized_start=23081
  _MODULESTAT._serialized_end=23302
  _MODULETOP._serialized_start=23304
  _MODULETOP._serialized_end=23374
  _NAMEPLATE._serialized_start=23376
  _NAMEPLATE._serialized_end=23484
  _NEWEP._serialized_start=23486
  _NEWEP._serialized_end=23540
  _NOREPLY._serialized_start=23542
  _NOREPLY._serialized_end=23551
  _NOREQ._serialized_start=23553
  _NOREQ._serialized_end=23560
  _OFFICIALVERIFY._serialized_start=23562
  _OFFICIALVERIFY._serialized_end=23624
  _PGCSEASON._serialized_start=23626
  _PGCSEASON._serialized_end=23685
  _PLAYERARGS._serialized_start=23687
  _PLAYERARGS._serialized_end=23761
  _PLAYURLPARAM._serialized_start=23763
  _PLAYURLPARAM._serialized_end=23854
  _RCMDUPSPARAM._serialized_start=23856
  _RCMDUPSPARAM._serialized_end=23890
  _RELATION._serialized_start=23892
  _RELATION._serialized_end=24015
  _SHARECHANNEL._serialized_start=24017
  _SHARECHANNEL._serialized_end=24077
  _SORTTYPE._serialized_start=24079
  _SORTTYPE._serialized_end=24132
  _THREEPOINTATTENTION._serialized_start=24135
  _THREEPOINTATTENTION._serialized_end=24329
  _THREEPOINTAUTOPLAY._serialized_start=24332
  _THREEPOINTAUTOPLAY._serialized_end=24558
  _THREEPOINTDEFAULT._serialized_start=24560
  _THREEPOINTDEFAULT._serialized_end=24633
  _THREEPOINTDISLIKE._serialized_start=24635
  _THREEPOINTDISLIKE._serialized_end=24683
  _THREEPOINTFAVORITE._serialized_start=24685
  _THREEPOINTFAVORITE._serialized_end=24811
  _THREEPOINTITEM._serialized_start=24814
  _THREEPOINTITEM._serialized_end=25343
  _THREEPOINTSHARE._serialized_start=25346
  _THREEPOINTSHARE._serialized_end=25481
  _THREEPOINTSHARECHANNEL._serialized_start=25483
  _THREEPOINTSHARECHANNEL._serialized_end=25536
  _THREEPOINTWAIT._serialized_start=25538
  _THREEPOINTWAIT._serialized_end=25664
  _TOPICBUTTON._serialized_start=25666
  _TOPICBUTTON._serialized_end=25726
  _TOPICLIST._serialized_start=25729
  _TOPICLIST._serialized_end=25940
  _TOPICLISTITEM._serialized_start=25942
  _TOPICLISTITEM._serialized_end=26055
  _UNFOLLOW._serialized_start=26057
  _UNFOLLOW._serialized_end=26157
  _UNFOLLOWUSERITEM._serialized_start=26160
  _UNFOLLOWUSERITEM._serialized_end=26506
  _UPLISTITEM._serialized_start=26509
  _UPLISTITEM._serialized_end=26923
  _UPLISTMORELABEL._serialized_start=26925
  _UPLISTMORELABEL._serialized_end=26970
  _USERINFO._serialized_start=26973
  _USERINFO._serialized_end=27307
  _USERITEMSTYLE._serialized_start=27309
  _USERITEMSTYLE._serialized_end=27435
  _USERPENDANT._serialized_start=27437
  _USERPENDANT._serialized_end=27508
  _VIDEOBADGE._serialized_start=27511
  _VIDEOBADGE._serialized_end=27735
  _VIPINFO._serialized_start=27738
  _VIPINFO._serialized_end=27916
  _VIPLABEL._serialized_start=27918
  _VIPLABEL._serialized_end=27977
  _WEIGHT._serialized_start=27979
  _WEIGHT._serialized_end=28069
  _WEIGHTBUTTON._serialized_start=28071
  _WEIGHTBUTTON._serialized_end=28118
  _WEIGHTDISLIKE._serialized_start=28120
  _WEIGHTDISLIKE._serialized_end=28174
  _WEIGHTITEM._serialized_start=28177
  _WEIGHTITEM._serialized_end=28367
# @@protoc_insertion_point(module_scope)
